
# q-expansion of newform 29.12.a.b, downloaded from the LMFDB on 07 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 29
weight = 12
poly_data = [30797548279705794248704, -9478460460037847384064, 709645914927917694976, 15507015861824716800, -2179155305696991232, -3617975849298944, 2125122050961664, -1439668569088, -951901011680, 532863376, 214206700, -42196, -23517, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-1859449563460318942044054679071617318117604682743029316249734484590592, 65385093596826497687134561794061906957393846066193683046109880778752, -5507481437886512521327776098147204454898327864507349017653446385664, 71402726746631127100125990175859962893403980678062821350622734336, 17518842669416616988701331513343169022600396251016524002394957824, -390837673099493118659035112238654832698775218251862362509405440, -13716890265744351849484483427818155297074556549332513681439360, 303181066799822915798995279229346983775440645211852051863584, 4550952552600876298845450833279270479780480652853611665600, -93916905219779384261939653545227985714210984813659466476, -674505822206201681077816319295764001447301128148177880, 12927243570549188742886748575537584932294625127428025, 36404151233521557746685615669404636100293077626956, -653649087809798562284543549857497042406658132365], 445516141528901504991707371899592668099280912764923479038807244800], [[362515327923209885271917909488985953304020815852886426679342142062592, -66721642021413202202109683909760684961691688804488453483226302513152, 5952997579415414026319483470046797122997608777272272496692253630464, -71402726746631127100125990175859962893403980678062821350622734336, -17518842669416616988701331513343169022600396251016524002394957824, 390837673099493118659035112238654832698775218251862362509405440, 13716890265744351849484483427818155297074556549332513681439360, -303181066799822915798995279229346983775440645211852051863584, -4550952552600876298845450833279270479780480652853611665600, 93916905219779384261939653545227985714210984813659466476, 674505822206201681077816319295764001447301128148177880, -12927243570549188742886748575537584932294625127428025, -36404151233521557746685615669404636100293077626956, 653649087809798562284543549857497042406658132365], 445516141528901504991707371899592668099280912764923479038807244800], [[25863195986407508965575561036790513679559892075544872581371883572297728, -5143724384922453326381887040683630913258403489487269185862332965617664, 103965114580721151631073134373785953564735647408241683006400973043712, 13270842411481947072236092829124704593339539219273935528380861174784, -305128983739744522028482547696676812625180822592729553065598032128, -10336759247831242857240288237514384603930666036197787283201764608, 212933597634541192073877498043195330181415909591507073720328800, 3606135910724387630874338810757885170881083633944014163653264, -62083567734231415544608835880389534028739061834078950301708, -603940963538934777414990138657991277337274669628620024736, 8162259293155948137443807582080658900020207054606497757, 44866374869857088289005120350134946070648299629580115, -397899249431722255243423889415660988236794052110629, -1046512188779874925816396539686989653095503789887], 111379035382225376247926842974898167024820228191230869759701811200], [[1881781869111685986721535274282646221198561101625167040675101116727296, -363857819799452901665023961905663739024041969149725842537851941683200, 9142227927053595602083642432790396655968630095177889477572030447616, 703755704604412459136892234826468526158896317095549272436478326784, -27796686471190594571319513067427502007992448069348390029830179840, -279594506238434123184965155466339116805544852431221408937455872, 20441653932549268386338453218502259638351864050622962521176320, -29018916619048381946426359965597816738939988466216738967712, -6325165445661374279124585879072688214050786658632869743152, 36260973725919727018653259998168458449049300706058989908, 880867114871069226953365104988217457602327946243133868, -6908650654017049765793608154652918043211473437528315, -45185519717906655721925619719922758170172983704728, 407329077954636904806052175766052938805941422327], 21215054358519119285319398661885365147584805369758260906609868800], [[67320133467079335317409656073873142232228418879824197512822981294817280, -8027763358381829781079033222695157635014206989576295788766138079772672, -148571347298928502286955247838378989302794098062081032598113069907968, 24324067161961061614919000409053079392598476366707201880356040267776, 139030217285618038651097888845076317384623499648474840177992610816, -25766215177964908232827259121084812538948414947140988053684475136, -94744376255895951655954409414349455654108589779128754891188480, 12548051859266473545026840299921929232730038859702912986278880, 36250002501719103836247493251384149875492618624193807995984, -3045082963531558229347720909961680029882015346938475886300, -6234618688140921782041532492638616111850052343361517076, 358281871129732186180160196357316580763127141307008905, 375867725009394548161309283788877051158323521210360, -16229974849512533587985796795416338456541457339869], 445516141528901504991707371899592668099280912764923479038807244800], [[-15157450245175747559959235255216884598467783835182096292927422101979136, 2456541908508954532696910820517591818175620224565856380617075245383680, -66496276689709408792677268245183896586453119023185222641081380417536, -4715501362506592941313661378366010458863401389135419459082492944384, 211087743623453622701140632215520440690813838819077792247244992000, 1573291017143657977492572586967070216039418432818351370894670592, -157442118589570652063694654203115798082779026884440509682729920, 503236608968359368654056237051138294836937532415179150347392, 49405169387686169352826679525912772047985652714776304360072, -355987660729717655010406172091560766661320879607663823828, -6981334602740912781828132956880100315328527131582232598, 63764509782889886876745828049141186780408201462787765, 362994459360835695239601608280084978520884980511698, -3689187274573069974258908253926798128495265780697], 74252690254816917498617895316598778016546818794153913173134540800], [[-805484915908819319535574835176926296985354963774348083000160297156608, 136194860767414792092847388926695444721540340266380242936044170117120, -291023710343418237044400085320556484251754394450458141258953228288, -419432225554873746329564919008853394492810920099624906931239073792, 2901432665481535527529459942433625314050324451911364340393128960, 418913587310872143018151636610096373127942506955024230279849216, -2053641633478713078963908330659562674110820328753208345935360, -190311923419058900704779295572982843389546916337410702889824, 531731608468444793934248386954635559145051755494263482256, 43053820329019437398525095417544111920934432233051605116, -57702417325391064697006030333012424449588192846306804, -4724751548962216112355038787768402053986256438511705, 2187121101373974979887942840876946502518624338544, 200145701438248756747488045581340246266097266669], 2767181003285102515476443303724178062728452874316294900862156800], [[112729866368207358215841930211541690299722289268235820387431869220126720, -24034485598728120052246769808080287615735762720430597838059123029835776, 871832790360975517573342055265151027352468093212807073301714460942336, 43854797365954634120396760552982259535592143902576098798590693500928, -2415819956692442862075299684803715753741164800141490779515952054272, -11170081553375222205079763816920013811323370696884479374804334848, 1759878968400556366566237539016079377102418322703583376863877760, -7409480528455376978148846961905255248144706230666537152772320, -546133485226834028376580020853094058193161213593806240374688, 4142816289676548449507788631280444327648573000257784375140, 76556203148182460755920567688290004040345843731966880432, -706186204384267927857985203857307899693812394399107435, -3955306858502797058389627144644525840439805262114860, 40004916593763161273520641345906636512661782366183], 445516141528901504991707371899592668099280912764923479038807244800], [[-722544261348181428940940871899724350879171456550030646772056324046848, -2592656684654893338884068449814621943360077007259131796620402334629888, 383105084698784948772959734488027899752573661837685644710300442419200, -3129905322439510059659509327105021053678951372777766607898825709568, -876225608377239021476096683190418779583469002906482885795152214016, 15052825887525100853231912407325079366066592844802360410617381632, 627920613794826275505466362844421975519980377120787676553845120, -11550792557897723373530169310143165228342903294301339511509984, -198277566434698247563337912836834413007176631280277124454848, 3574165223330833758088166901729247647255591873197977233236, 28482244817992394889970944822689153606346466858539932552, -492455046973399603547718211305187627348870172500432535, -1505873893963629085030952072945733742646555377511636, 24933598392244793343223404282879497619315357242883], 222758070764450752495853685949796334049640456382461739519403622400], [[-844048248451838288306540932726470077185782715917742338268079910748160, 211221992136817594411429314373200334018461479299297916820029440049152, -12926949806587547398395441458268280793126629194833617434721749266432, -275861958738693115665231100342189551205913834614001391992305094656, 33323768810781072889087824980648048600072584684820830908023440384, -151789613568047993423324052771074823843991168737869058497800704, -23965691853283205615140023676800649592643704571857002504030400, 232842233492714447632769323638520392966622266608371074050880, 7407518295624820939575644321951850809511690206628392154816, -85030397781984270076746165356206077137936929919601136620, -1036637496163167901055524864699504568326630892149762404, 12623743182022880730510565559411370751348802461173835, 53515457843778391821544820794307276415616306782720, -666531094640350299722640085318670461755780587951], 5568951769111268812396342148744908351241011409561543487985090560], [[3240663367922991950730481310362544495285099203453049557031499057332224, -255598438757378544016091588152384257756109015375445321496618584768512, -47265141035305887070854320618180942083055679766622387867802162683904, 2272201502901584526608959745493558467838043256970948278168266422272, 105439466138759358860345095609680909977218938889322530245460248576, -4030730652057967894453189058145995548357054298095920796838840064, -76854999232978574512943462422045039242972883447694807402480000, 2520699421913425973150473321726577437051049619196097855247712, 24844187304815613691719371017895245557217954944112795841536, -707495282012099372857703275385678996473284708457530289988, -3645738729543508064779758262566355363481945601827011544, 91623414891321127119712808870170251738459293050633595, 196107658727074076731441649029115904939476163865268, -4439959296613794315003428809857790869397753990071], 19370267022995717608335103126069246439099170120214064306035097600], [[118515437516301603300298561993208795908505114596814499167425787256635392, -13900741247511388421125532678589656347901113788420049424720629492088832, -1140764292806502364004933160797757466178550191247667004424244205510656, 77626382930687153133974416038850319322938718210019542373108611835904, 2389495467040602106650360834893895321590572551131950588346419798016, -120422252604246640479802364923321975244256344931369122893293676800, -1737768680602693051118320068801424325674703095312172544487187840, 71590730707549475840148916323854385235699270787752696452797216, 569899032487959331813041982406623580281320780729674624449760, -19535778166735214414877198940746107013614197594628534229724, -84973786131091508446301830275893824883492600189555970160, 2481787537577777865922598143199617182979805574860621925, 4631275893776986769396694977353762662801243266673844, -118573640037792468148466400352453775860491237307945], 445516141528901504991707371899592668099280912764923479038807244800]]

hecke_ring_character_values = None
aps_data = [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [34, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [698, 15, 1, 1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [6077, -161, 5, -15, 1, -2, 0, 0, 0, 0, -1, 1, -1, 0], [28433, 3435, 11, -294, 9, 2, 6, 11, 1, 11, 0, 14, 8, -1], [162318, 7763, -59, -464, 7, -20, -18, -13, 31, 43, -15, 4, 15, -23], [401231, 27783, -1201, -408, -18, -152, 38, 98, 67, -68, 78, 72, -37, 62], [2129477, 42673, 1303, 6707, -35, -46, 184, 87, 177, -277, -112, -22, -34, -49], [3759645, -31251, -4183, 4683, 193, 140, -388, -64, -2, 786, 127, 293, -979, 176], [-20511149, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [45276315, -247691, -27153, -92624, -1171, -1392, 1726, 3336, -5112, -3366, 1305, 3149, -4969, -1128], [34879270, 546924, -49826, -178890, -1932, 7750, -12732, -3242, -10006, 8376, -6504, 722, -5024, 3482], [14175037, 954961, 23063, -91852, 2808, -12480, 21266, -542, -1471, -4098, 4144, 5942, -1077, 5846], [156661479, -2315855, 30227, -367568, -6885, 45306, -5564, -9291, 26769, -28551, -12310, -8910, -2774, -5871], [-298326384, 2219680, -139396, -779549, -12192, -11396, -44052, -8605, 21619, 5315, -19625, -48439, -1589, -8817], [-944820798, -10611429, -590827, -1266308, -50187, 198330, -49732, 2827, -50317, -34575, 35127, 72218, -173777, 14773], [25144121, -22144799, -90041, 2424447, -15531, -250060, -34502, 119050, -16042, 36436, 79851, -88205, 80185, 22778], [-546830859, -41037941, 466719, 5760280, 48982, 124110, -110440, 69396, 106611, 154020, -22570, 109702, -13753, 12152], [1555939850, -46627916, 372734, 456382, -289362, -31254, -69468, -111634, 303496, -136792, 67456, -272068, 263914, 18774], [-398316696, 32443528, -16960, 7725822, 6552, -51240, -37640, -19448, -182680, -350808, 93152, 143264, 193112, -54664], [2833908108, 1418178, 2100304, 2206530, -264436, 569238, -43444, -410142, 201072, 89136, -203864, -121906, -268418, -95386], [7541192582, 69202122, 1655604, 11991767, 116362, -498016, -23182, 237067, 230285, 844819, 345943, 434135, 472399, 305879], [9132405151, 17319037, -784383, 8048689, -333413, -1485494, 646346, -208200, 149670, 7756, 49139, 85743, -273697, 93160], [13413415261, 166735373, -4131441, 4390610, -822378, 332762, -494582, 171612, -258885, 832568, -71074, -960782, 1486585, -70220], [9804399069, -202835745, 2579087, -1105460, -812844, 3992576, 176182, -307576, -129953, -1623310, -239132, 723560, 2023603, -584696], [-1683597230, 358715650, -1428602, -27894658, 307420, 7504846, -271176, -933364, 265852, 1453028, 16732, -1293888, 271412, 1020148], [40882897624, -224356778, -2553580, 5478470, 1583960, -4265086, -587972, 1615428, -217650, 983590, -1110004, 983416, -1480338, -535532], [7371240861, 1706210579, 5825251, 37648469, 187149, 3053098, -1733626, 172880, -1894982, 720256, 1932861, 1154649, -447127, -51136], [7265402402, 477924821, -5709281, -128022139, 246464, -4824451, -60778, 1812174, 1089738, -68316, 113460, -2660086, -205858, 1577734], [22934985682, 1937874908, 13937040, -63441718, 2056118, 8677522, 2460028, 3475918, -777514, -1157646, -619042, 2164624, -3468038, 962146], [-47455893501, -529606955, -37456339, -92258535, -6631821, -14601892, -757612, -11223735, 2514957, 13029239, -1202804, -2021846, 4141676, 868393], [11803590011, 1331509859, 13052147, 462254365, 2653611, -6110994, -528470, 1801837, -411871, -7390079, 1465506, 4827502, -13256360, 4756133], [204333182526, 673228748, 8402618, -370714504, -2515154, -13162500, 509328, -6443928, 6863304, 2003238, 3039910, -6417518, -3540138, -3302464], [206062536313, -1693076225, -5924025, 226157447, -7748831, 2830134, -13872418, -3946242, 3480732, 3487870, 5325183, -13292313, -2815073, 3631766], [100353479670, -270945603, -114240573, -430545198, 5502293, 14239756, 7012752, -7406529, -20683881, -25063959, -1906309, 7196534, -23484153, 5169409], [269114026747, -3356875607, -107438841, -148259669, -7497929, 28557074, 18400000, 7686004, 7830080, 14314728, -11379567, -15127221, 5849045, 2357356], [21876390883, -2374287521, -229529137, -148242322, 10826046, -31206556, 37850420, 22716108, 4420017, -21793960, 738870, -1395938, 26258589, -5788560], [93798441278, -5796995104, -85507060, 830130349, 22876760, 56523060, 539184, -13190270, -37617214, -14087954, -1504390, 32457990, -4102118, -5462134], [-332482391010, 9718855908, -299651834, -23711840, -20323454, -82483690, -54663852, -6194444, 38649974, 13920886, -8459806, -9999934, 11261892, -12375308], [89408535676, 3505043242, 238387582, -459544256, -29959432, 6867648, -52483984, -52524328, -12017234, -12936412, 12734668, -27710816, -59402490, 4779016], [50577133948, -8976211776, 307807812, -220419966, 25895548, -73733020, 13417732, 25920572, 44579512, -4299188, 6448968, -56910824, 67228128, 1223060], [620801227288, -19100075381, 384406861, -1134924463, 1209578, 18616171, 10593416, 11837462, -7794656, -60508282, 20816786, 12612724, -53931208, 10789946], [-1630871629427, 652254759, 259882909, 2040307955, 1352765, 67767800, -3072790, -60918915, -53776893, 24239171, -11030136, 38672604, 5893580, 2363309], [414920910717, -2133371377, 861929091, -3206530886, -14863074, -165159662, 49301882, -2827314, 32555301, -89244044, 13676794, -69052204, 43396613, -3368662], [-570238570202, -494341496, 303686000, -1218448684, -12735896, -313204364, 27189668, -7082004, 70291704, -3736224, -17478236, 26609692, 18539148, -19139468], [388839180597, 11350641411, -20743899, -745644439, -11875367, -38329850, -111855172, 3620664, -97695168, -11107016, -9180321, 6239337, -148987037, -27012784], [1325641860672, 21239711778, -211195232, 828381303, -57355874, 25174360, 69427458, -7846626, 149965248, 135107482, -9878082, -98886396, 133441150, -35453418], [-654694504826, 11949490032, -1273644690, -2775010792, 110663986, 210821662, 101482560, -58917042, -29226312, 25195344, 105137724, 149398456, -15184574, 100638862], [330606297452, -12772315838, 342260376, 4651306234, -53248360, -191569890, 43634048, 45548122, -39237292, -18022656, 47106682, -206178998, -28538800, 20894842], [3214898091805, 61756387527, -43056903, -784680620, 21161016, 281720282, -88248900, 46975736, -216135269, 181069474, 78475620, -30769344, -142386619, 84360636], [936752766829, 6822257102, 608416430, 3191128174, -54393583, -307078488, -350704630, -87082739, -47229760, 141796151, -116297989, 2369660, 28601710, -65371101], [1980429691313, -96448388251, 1808529309, -3286053113, -195016363, -540954988, 94753604, 89305254, 28130028, -182692356, 80656689, 71093651, -101560369, 67062814], [-1055214180751, 67284550906, -3205867102, 6722744898, -338267525, -95386018, -54674368, 27771893, 391127980, 202884997, 41218993, -348799202, 415517390, -57526313], [-334942103086, 9607133456, 2772181318, 9549547671, -33654172, -261673676, -324854526, -56973846, 222916644, 229599050, -39984800, -383310282, 461637400, 18176890], [-4256195871219, 1006326236, 3778883798, -7651279663, 114149412, -403796131, 816498900, 188657138, -1505507, 38037242, 95969636, -156261610, 106955085, -24107510], [-2087658827643, 20717066123, 1205746259, -5959342402, 249066175, -792361336, -311074976, -70453328, -396898294, 55073702, 116995925, 873429475, -585906069, 94455568], [-9957421147167, -41281116683, 1397805311, 4982368262, -556498856, 168474612, -635505896, -246088720, -516700901, -227273422, 36932760, 116532864, -196825875, -148756940], [-3066350608809, -53626870663, -4681472059, 17823127402, 369141689, -1295964408, -88192184, -65293546, 545276356, 65245004, -368597499, -365847425, 213114319, 18631814], [-1791039523734, 65898258752, -888571560, 21812225608, -21378052, -960162308, 323455820, 231442516, 76402100, 459487144, -268023848, -227147832, 11004884, -24579012], [-12011821380823, -38960570304, -2796697616, 12571866130, -175557079, -652964466, -242362360, 504260379, -633946002, -549674293, 305242799, -507898530, -272948880, 154032697], [5617946628129, 172223804865, -1491106193, -38743389121, 43845557, 795756696, -200027058, -258980386, 258102742, 302455844, 51565643, -256628753, -86683039, -186852066], [-10308962491580, 158341223802, -1195862710, -5147875874, -217304498, 1282784006, 17948180, -288221806, -878130368, 3617018, -201132106, 194245908, -934233692, -430096298], [17910880989249, 26814956795, -6214350819, -8615746294, 257034889, 1166856714, -1550806184, -240773629, -927978425, -572015001, -407695294, -174114766, -67148114, 78725423], [261884221345, -216775781749, -3000676339, -37452107401, -795949423, 177971660, 430945094, -80991991, -1017993473, -950908225, 165310672, -751968356, -1685775696, 744479137], [18657733903231, 73086629168, -4418397330, 25490329145, 258131544, 1553629399, 889404758, -190570084, 762837805, -440148270, 100820464, 282834232, -10534523, 236794732], [10007097383237, -167540732307, -2104480577, -42233268446, 1558492480, -1513113212, -1055380636, 499839356, 1285921183, 759899602, -34583028, 539294332, 136262661, -199398072], [22490894841002, 535296225356, -6039863354, 17952185017, -1076017792, 1868662108, 353494006, -235742594, -432501148, 2325632494, 415349748, 2141834646, -497019852, 841892254], [25523768066595, -166056593373, 2285389375, -38440167694, -1516939740, -604381494, -2347875238, -232646476, -366172691, -609924814, -154895988, -547835788, -1067023891, -551798324], [28558230961064, 296951088084, -3819336844, -34894779474, -695571928, 4206619924, 508230268, -985006128, -1115245536, -449713788, 2145945696, -1825726840, -1200723172, 357403416], [-4060676382222, -104541337599, -3554904397, 98189855890, 1273429355, -515987398, 1966424930, -224726101, 755909791, 1265290931, 1244284941, 1297599016, 670862503, 658947993], [-2844835837404, 815070011932, 9616906728, 45134954530, 449633054, 1809192704, 1794656002, 1856134960, 1401858830, -1303514286, -17759426, 644477542, -375981622, 77551332], [7729664214606, -18211644750, 911433328, 940093115, 29962738, -1595828400, 168844986, 1872123681, 972516399, 2062063797, 1886931977, -1344451895, 2838318269, 351153981], [46825160776951, 320785757689, 2975794767, -26440980387, 1065851123, 2670404020, -1768582774, 104778257, 2370818443, 1287948435, -239997926, -278619690, 846842778, 581993433], [-7536304172798, 791943941003, 9504603921, -27516376375, 1386902854, -488818111, 4252664662, 2012562980, -1466546684, -326535058, 1264753766, 550823754, -720494732, 521070960], [-20545939136667, 68787316969, -10976238677, -37915248177, -180553995, -6567508586, 4055406500, 730831823, -1081087919, 1108684747, -2074934744, -83509374, 2063739754, -1617690225], [13348554663271, -588897695213, -2740453313, 6719427271, -703846925, 4943986424, -827408824, 3049271674, 946661324, 777270924, 945822035, -753566835, 617200713, -572788382], [-23403397285604, -104337371674, 20939417656, 14246603984, -1614230414, 4354839136, -900226280, -556548896, 1234437110, -1861665598, -3109177722, -4047723746, -753609976, -463583080], [-57316495395902, -791815067171, 8274372995, 48457739917, 1039828566, 783640135, -2835608800, -1870871414, -7194373150, 2706405670, -950984502, 6841111660, -9477204854, 275159766], [-13589907729565, -1082032038510, -9765903746, -134689609696, -3248708901, -4335241696, -5661049144, -3393682299, -1308996702, 7471897837, -87993983, -3706016074, 4846692944, -792104449], [-26630685813802, 926935205160, 6297519320, -37196472808, 66383948, 4872564996, -4743075908, -418448684, -4669839556, 18754440, -2685647460, 7587687928, -8277757968, 1204266164], [-27379275626234, -1278801699368, -66054887738, 80669270168, 544226582, 2560438170, -42637332, 2383380020, -2106704522, -7107318742, -1736472070, -2247081458, 2813713412, 298214412], [-99003473398601, -474935062149, -64336489735, -9256437248, -3380999610, 6491081202, 1611820836, 2377497302, -1854805697, -3734188412, 2587006786, 592639176, -460175795, 280670398], [121822316277075, 1514304230865, 450707447, 33318485909, 1772311887, -408211846, 3244277104, 109457162, -7991162378, -10369992442, 3581268191, -363386107, -9354485661, -17380678], [-127055432991828, 2318665529670, 3727816648, 64819432778, 3776475680, 8654095962, -416087272, -5792038250, 2088656636, -4458936748, 1317793372, -5623051738, 9625962758, 486332474], [77982009351951, 2675527442447, 56796208119, -61481688811, -4608301341, -11281657648, 3615620256, -975683404, -227426210, 7437339954, -5243532035, -6278513021, 9658519939, -53681836], [26006860109501, -4281223615119, -22625964401, 68664630503, 2208158533, 16621117586, 1460103924, 2481091457, -3938402309, -3720243823, -738213218, 4561449408, -10402333480, 3989765377], [21447365870540, -1292691059988, -18818791906, 56475473572, 8829198088, 18765443920, -5358215360, 7725968462, -218944208, 8095150440, 1169054468, 5159692046, -5531586278, -2206763230], [-163347728225248, 190908042940, 11850476036, -4984814658, -3147163526, 8378554112, -8321075534, 1297485816, -809719194, -3420290466, -4133815090, -9034587902, -10155533686, 2848277284], [-103562245231874, 2149661550190, -67877853464, -383127499398, 1630767750, 8112049278, 10668060364, 5765677952, 4332830584, -9309666030, -681660902, -2439308222, 13414721422, -1020724536], [1240364590653, 96054989561, 34160596757, 247948917667, -4082512231, -21728418856, 3785168880, 4219969142, -1365524636, -6947923252, 3268296081, -876002801, 6679433011, -3900982466], [16833440793707, -1433946104227, 42117806223, 121926361488, -5079962557, 9220406694, -2359064188, -11495331799, -5774999771, -4491340483, -61232318, 2761084438, -5730302574, 5409136477], [-62753098717253, -3734046621179, 39093006719, 468915775610, -11159964747, -20764084572, 7226597078, -1216406562, -4831742550, 9193641688, 1627809531, -643710121, -728834715, -4279766306], [-35203282499211, 4552827302813, -94123465339, 203670154589, 16545963349, -11253646312, -5463365740, -3178140494, 4461761924, -13553802016, 218304629, 6943349527, -17037128457, 1389310106], [-122703590848611, 1088313333459, -106871304491, 329777848748, -1375244091, 51379125154, 1945266744, 2629765639, -9356520889, 5821678723, -8947499398, 7182696346, -3325486774, 3125785971], [136395853860203, -6217582474341, 123580049281, 512097200369, -2138909609, 3059849480, 7468881554, 8795655472, 5548636460, 14104044070, -1849174797, -5874037921, 16451031881, 1679129920], [61071825207071, -2014596322155, 107520513855, 440261924470, 5196888889, -939611120, -279848390, -4146312846, 4498926222, -9221751352, -2135318113, -9933853465, -5456725507, 2996060546], [-174086991976860, -5215344330833, -16443077415, -72151248516, -1031278583, 27592571176, 2624050010, 9105972889, -7174530433, 11607560245, 12775278743, 9231239840, -20153864337, 3085113507], [245901878348827, -3420699734450, 78691468352, -376572459363, -1344692798, 26833837791, 6840344014, -517853006, 2693092943, -11330194548, 6167200470, -7267914708, -6043157665, -1862961866], [1965538737596, 10155052225136, 68103846360, -423554084284, -7309832696, -21496276160, -11643537952, 7547202086, -16534278506, -6859743026, 20228166206, 10563523354, -8123560994, 4522672862], [-112530771326750, 4856008275988, 73402384778, 236831294176, -14986585430, -57932890700, -15748210596, -4088896980, 21355477440, -3243387226, -11164878834, -10313008534, 22718758918, -3760003108], [222166828002343, 3211945381391, -76813674815, 619402407367, 4131711611, 4226224408, 5800704382, 7734643456, 11382748520, 18816637102, -23538295233, 1001627739, 25734841797, -4087154024], [132766425444862, -12807676618070, -211775575482, 594526105454, 9441676842, -11064849552, -30922619718, -5400820428, -31179612300, 9514463838, 353555510, 13150776054, -27572765336, -1438075264], [89932198430942, 1749499421368, 238762219234, -1172056327063, -15742004124, -40510834108, 19628344294, -5440086498, -5277820884, -23195420010, -11791132424, -23535076182, 3242860832, -15638119954], [-314392659431690, -13760501678710, -214992955352, -563984962368, -8358695416, -103506191796, 15902580868, 1682808638, -587113322, 22160411728, -2623457052, 22716153902, 1562354344, 9753209826], [258376281698534, 1787762449690, -30139549826, -651965316730, -1790034226, 18942681276, -36888728100, -29247533284, 1449040252, 41490744672, -7365757654, -3612948750, -12580571194, -7005483220], [135650927823441, 11814042647667, 162610838253, 20676139732, 27611086538, -31265288324, -22006409594, -13633737704, -4699212349, -16622330812, -1021810214, 29107641362, 249253157, -8785271744], [173713879164455, 2916208201753, 31018877001, -39309896139, -12146861237, 31234698094, -8954948450, -2912218474, -24777923576, 24072215738, -2342156079, 28998834897, -27630440499, -11596864778], [270514489355443, -3332349848094, 463500314572, -1004215827557, 11212805224, -43400077867, 18213397214, 36193784920, 8374182773, 9132841790, 8889195884, -6750517508, 3910324893, 4346357144], [-82948085337704, -1878472807656, 236397027156, 515762431577, 71118860484, -38810167772, 1975971972, -13820686623, -23367124155, 10454540481, -15452691967, 21444787287, -45237693911, 4188252197], [-273023673855985, 14906822880231, -247807724959, 374809813902, 3710681174, 121871194650, 3467138078, 12139019032, -10258507471, 12880461928, -3897458270, 20640364734, -29580519625, -12575081808], [300864317625615, 5430252216669, -150881867601, -534594363654, -43329046187, 55690011052, -24477898438, -7654602246, -3238147074, 24125902656, 7674889135, -44746927109, 6125360277, -5721090590], [-559057365241888, 12200126697435, -149483240647, -947866692039, 14034816024, -47044267111, 20946777010, 53631967834, -29475993052, -32435428944, 23518910324, -7971793258, 27719884124, 732337226], [275168623093670, -13782287955636, -91898981470, -1551494123336, -39203527818, -84154067296, -10046395368, -34615030160, 2536947956, 18981996558, -3746419950, -31556197006, 34441954294, 3498987248], [-342360513808, 2901252363698, -154247954824, 146286516743, 40755471858, 81506099500, 25751850486, 40944043472, 1750630306, -35870308592, 39127227440, -22549812642, 80252245764, -290568304], [-37110332440062, -3895585836448, -287027346610, -124045302796, -61805937650, 115559474750, 23186084420, -11334101314, -85445961308, 16009400484, -1070189364, 12387047636, -37583483430, 7697605630], [-660354550503217, -9532390505921, -90456831097, -117776449540, -36697076758, 25904254232, 14740293458, -37759847554, 81558473155, -230763772, 2231829874, -29789252504, 84483205287, -6506853782], [397868996427553, -10142206909787, -13310586825, 456671232081, -27646019543, -144078229932, 21020337902, -29797532600, 47280357008, 28961985186, -17320951795, -67218654471, -2484405261, -6324953288], [256923775271993, 2901375323021, -257685976547, 258075245299, -17759917775, -13345064092, 19484340672, 18248038052, -43670757914, 2506264958, -24153072249, 47494339161, -97568996139, -5130706764], [100093589869755, -12045561199491, 448484040655, 1635052741522, 17959087254, 136749050112, 48233866244, 65943019838, -40942859573, 3348495468, -4496423110, -63226701632, 48898007649, -10866485770], [212457694592696, -6543993979378, -868483620950, -1672048783079, 52337417454, 44604719580, 36707765140, 75973666288, -53475403780, 17992259116, -4720380806, 28484443198, 12191433426, 14485083960], [1859732412969438, -8385581424278, -703104105634, -114304686390, -32804989774, -24307103848, 17213468778, 42677665936, -58263835576, 20739386458, -19325704010, -24727138734, 18258303632, -1136641004], [699416130123915, 9328270231202, 53132084234, 261654077554, -19051558909, 24433448344, 21193454638, 64335641483, -4776178652, -2154167631, -19444755099, -48613828992, -23004738386, -3793530947], [-222913330363240, -6687899249658, -861225950450, 57225886050, 13653531370, 43004297666, -48564915560, -37899275942, 1139186372, 17373629550, 41507369050, -40380752760, 20014136608, -2730540058], [-518400211113214, 15196563091946, 703164650698, -1214315236222, -13106758574, -117471263928, 89282408480, 70106859062, 46092276538, -13116610814, 58665248944, 25882219276, 24771017612, 32032209862], [2109356644872518, 16134932270796, -47600989214, -901789870290, -28073288926, 58514725634, -16530749048, -91854719970, -92579284272, -32601059680, -18072617168, 24408348456, -58057598906, -11624524666], [673842469834086, -2983764977723, -108707515361, 3073489240828, -5420811953, 121011683246, -25041865736, -30134180863, -6301033487, 69806668931, -26969578887, 82375654710, 7873874637, 27052318111], [192461905452118, 27481119148263, -628712789311, 81787896314, -76663933459, -20753717670, -120453530782, 20690429857, 50962110341, -45922518431, 43825295379, 27934796220, 574011525, -17077404109], [1168513517528374, -8825440883456, 165475248054, 1034196145956, 11564395998, 203983272798, -27976888004, -3543009354, 56203451460, 106831945452, -107594269308, -28115916420, 147285272322, -26258522042], [2396615428105845, 12678014341779, 461963543185, -2553827919213, 13821689517, -12926044248, 565989262, 53095324217, 63772699939, 5547985099, 9376995124, -26151692352, 190072301896, 19891159889], [311902302085824, -36025288929548, -254586603020, -1728834501518, 29891275656, 99116667926, 25035879044, -75593782060, 24082316374, -55733818012, -133689452356, 79527917876, -108115427106, -35226882492], [-2237755804294054, 30749008908748, -127952085512, 585068754135, -71709298332, -49787192636, -49006250752, -3276826132, -185312826764, 5678649648, 4653833104, 13420340752, -214180444952, 27301325260], [-1289048725326527, 35293432182747, 736573514645, -1851182697177, -42068126067, -238093542820, -161012552686, -20265225721, -92875199, 149255518753, 51089493726, -66652511358, 191927746262, -50359230649], [-520619828164143, -72820100561025, -481088259855, 183318083907, -14534952219, -18214839208, 86069704638, 68647601699, 4036861693, -6078546287, 104737799774, -3834035490, 103155475458, 33365208659], [2382158198059393, -40143697460107, 1018641164879, -2297062020704, 127293385222, 194115388714, -103462171868, 32103731358, 27520570821, 185233747280, 40636721598, 72992813552, -47236086005, -15605918106], [-2936380407641748, 38998346868932, 316686120692, -3545284190694, 15246148058, 101682049600, 50893900658, 50448995212, -59353127206, 99579675522, -59450525882, 64336434046, -32779694926, -66205701920], [989423484264061, 87978375543607, 225419210805, -6270603610654, 44765287488, 113257328690, 295947702498, 84208153734, -34280365899, -47144490066, 9546059624, 97043262402, 156554235667, 19244448242], [-4778479490693235, -38186305713563, 1568703230293, 570984971260, 9991920228, 131449739742, 126976991768, 116049548574, -44177112567, -195523600822, 94528713372, -6069732422, -56120324919, -24435855498], [1846925937889442, -6583002660188, 42109677774, 10456948578220, -146975790806, 5548863354, -129533018400, -63734702178, -117215950092, -65296748396, 21635804600, -97979924232, -113731610398, -43070840410], [-2410317909760327, 12760726364595, 1315820929167, 858946600040, -66163301250, 340226959250, -108174007452, -78985433296, 71636425867, 200730735092, -100032095810, 8720338370, -54783423137, -57992742876], [-1346534507729204, -43470446475358, 598988523184, 27524904642, -96182208640, 98020217514, 103155363308, 60762114698, -53123811632, -186693492752, -27931919280, 17706251690, 292082370046, -37767540410], [4703739194368151, 24268372117189, -3258124353123, -2712809104453, 115507906919, -40944239994, -35945809762, -9859142346, 52416310368, -181781458726, 61477431541, 101080437165, -15933587975, 92493458550], [4737052831282288, -68026192361073, -387047632299, 919828214818, -196694108083, 95715436560, 258955754964, -35405954365, 241479854689, 66954472809, 676369931, -34198387662, 170130998117, -10958645827], [-1229921033277701, -5419740663359, 592029487641, 985209148285, 60905816719, -311185944068, 11366544288, 246216341789, 283433898649, 180490410559, 30210762220, 57324900658, 324334645520, -54462057931], [114890289268226, -41969615434812, -590224373222, 2539488502089, -34696115800, -700924501688, 20757842534, 66105749252, 92914973818, -167620177072, -190008330870, 21478701880, 5251045210, 57195968556], [5632793670870079, -26372375615635, -2304857925755, 236913211130, -57035771948, 247237467576, 19960437364, 23717537194, -145640770273, 168718371590, -78086441244, 191199744718, 7070183987, 27873474506], [-208316331949000, -134651120054872, 288581458790, -6766875174277, 222191701072, 402581562768, 104580708570, -82516516055, 265501680491, 160820213705, -46408588333, -219271822361, 491983028595, -53718210699], [-2308147658666716, -18863839511476, 1424501646010, 1930643694720, 7945064900, -340963277460, -311827676916, 27971642162, -69110789552, -174270245188, -85512103980, -39435208850, -123014314454, 138600532366], [-2954261557459233, -8204285783166, -981779567976, 7367887986695, 23419370278, 517577185195, -97817409408, -2348033720, -500784632515, 41555629860, 16559279566, 8461728642, 58556169553, -57615158804], [6753806848402887, -9905785729443, 956906147719, -3961466564858, 207392481999, 419767909566, 52255049404, -43747593023, -41475485671, -13703177075, 81377267710, 342529660474, -220585647894, 10109824821], [-5911606766807104, -46687203814086, 1280685558536, -10869709503474, -155227677852, 509899481858, -330827816960, -77158929862, -251652449228, 99275464600, 50777585694, 79552686150, -334684780684, 71490846202], [-1384161014020822, -11601774186817, 984591596633, 2765317241672, -117007864407, 32375068458, 70002362712, -48722220425, -302018712937, -624141547695, -105638374889, -250150376158, -124653007581, -166058558055], [2369063727368908, 37378079084914, 876515466662, -3373274433164, 440890374588, 715505134544, -83517624916, 177248209916, 84213229102, -60162257388, 95634228784, -222675243488, -187174745558, 50362452892], [-6813284912763967, -23076765780953, -1438256070649, -13186131905007, -44262530595, 205864279354, -43229959610, -33367311188, -256695390838, -156071033724, -121981316683, -62469807523, 873580349, 54579653828], [2460654059903405, -57768656515689, -3361546299265, 6235570685042, -330640842417, 612564841300, 292810133408, -98950804922, -430834091080, -223422153748, 219213594391, -99078765243, -192819302955, -105805370394], [4462267213531109, 135441097049329, -1950673001709, -3791546050721, 169128461709, -902360773386, -35074455280, -155446955911, -36580349909, 246027058169, -306140747946, 81684134072, 19537294436, -71344034687], [-6900727826693257, 25086950644581, 3455008758937, -5801797017846, -241845010751, 769617690876, 20140171468, 2767220050, -113875794400, -236082634716, 304010813821, -168922657845, -260534178677, 95811740306], [1051444029522198, 38244529577346, 2204511363014, 15891411512200, 211897914790, 379092424616, 6558469968, 240078660472, 460794076532, 96765446432, 76145306266, -69660618674, -101028059666, -216302046856], [-4978755256962626, -37099451298768, -1098468928612, -5206449136020, -97007186952, -629633731172, -299752534880, 156985227752, -138094648832, -79933073412, -240819200676, 5605840312, 163697181908, 209078289488], [6422893960281998, 144446450746990, -619835404818, 21092147415758, -8047874630, 738795296616, -203229999046, -3490655412, -522920299644, -34083859110, -47065400718, 473851319542, -673952899268, 76024705200], [8645241956007530, -30968844286415, 1830604845711, -9007265861639, 381676912740, 558038884633, -57102633002, -255863354214, 383515511262, 110947207980, -35140148516, 515260847274, -436525623874, -191646331582], [-8080498402021347, -103593051880737, 2900638659309, -1288378040938, -214714705567, -421848608742, -231261922152, 108776740229, 360812272729, -467967622667, 117052754808, -124585511176, 400815599380, -2736222847], [-131262694129453, 157088723561976, -2439037061552, -1632597544492, -475264006309, -300219252362, 36474732594, -195265825753, -221695330796, 107741298829, 77172098117, -85178376556, -863951867074, 41219909833], [-2427436749440200, -145633536784332, -856720439940, -9760378952417, -693764331196, 770957468288, 188261885756, -128014589845, 49562105899, -52015453297, 183486309947, -246753592115, -8183908561, 119798303351], [-3191507645104977, 24635397184207, -457012646659, -10874808510783, -201820629349, -896147972378, -189064909124, -270657575497, 188444114569, -575501031453, 128402160350, -592962802704, 481828120952, -159696623745], [2483983641534057, 208339507449830, -98812373244, 16370001588717, -398968977512, -374025806333, 157615767610, 179506443732, 643883678991, 326083006974, -104670728168, -24193738952, 761535674823, -147935627484], [-4219010852853658, 220644161528434, 5147528009910, -6799344138759, -212692119230, -199402398844, 259317243676, 286223274293, -96857084135, -302907168383, -182589011817, 467928044473, -376265275593, 11439296537], [-1624037003150308, -20227639679280, -4084737730472, 6228497914314, -53439053084, 919933483704, -312798303932, -511117480538, -421648363990, -391878367582, -77321031338, 305342669638, -1021080625946, 249338149134], [-5162560830327684, 59536969610720, 4241770148784, 34358166919248, 197351290018, 266867154824, 826286794204, -63157278870, -413359459668, -922777733674, 26441329174, 127682581400, 207039997416, 106394516182], [19829075830853337, -100596797882550, -2855201248052, 21741229816733, -92601060532, 2366115408411, 979347696142, 337760777412, -971239621893, -948111433706, 417895283532, 331284852340, -926632516861, 322354435580], [294753619014330, 125892783281772, -134285310618, 31777791476532, 41567414946, 352934597240, -895908321384, -687984442900, 140821995328, 46974613174, -177036221986, 242101863306, -62445832638, 111847976420], [1395259688208705, 80640874331033, 524633116859, 23122457408089, 255634261717, -927052155332, -438567790334, -601906026308, 283864096460, 282086048578, -333071535995, -671699533423, 186600728935, -61935202460], [15838819710625530, 71130458191229, 115816630443, 21533458678691, -100505453166, 1692912306391, 85447754930, 83325338148, -187598170008, -618798034050, 829125811322, -68079826194, 48983854576, 353400299512], [-5661578172828186, 340192864547548, 3578513630322, -1145198739480, -19324502486, -2123044775342, -14132518152, 497978802564, 30623806398, 702134142342, 493091910046, 59204653810, -140942643060, 266523608516], [-6020966561865422, 20096403530682, -6725708238336, 13012286602360, 167642469244, -784216870944, -471263410792, 121738722122, -98739115406, -1344352143744, -153678596624, -389006981626, -358014533992, -197886287554], [8068615632336959, -179859441275391, 6942684564063, -12475536202579, -185066457781, -126129832474, 490555883816, 437910306748, 664324318616, 104000166720, 126171727217, 559502916391, 405887844349, -430798074580], [4843624883332996, -96962042714028, -1829023694816, 30562612359558, 315038489690, 361509873340, 564874302378, 268595038140, 65302406586, -525028443314, -329812284854, 44546181526, 193278432238, 97763546840], [-545012574649060, -98041325613204, 4396023055220, 3835221651808, 982244954708, 274607697128, 564912265572, 847598387742, 538070298894, -535427446094, 747342756826, -774772830146, 369813682126, 176484978014], [2294278485577877, 143397803222651, -2790180127105, -4880714505072, 540038772594, -2962519509530, 773957982612, 529513401580, 532546450079, -148370596104, -848565160810, -460330518886, 1373304638831, -514893918032], [-30263374993679474, 272746896002210, 3644327948760, 10442985846503, -593345457542, 178140771868, 324098605862, 625200419, -546853257779, 365153783515, 95905240703, -517422391961, 725498154931, -101052053257], [-219838425006000, -317660155910426, -7213623861882, 48430378418176, -87909544508, 881759183712, -768727628524, -1333801533912, -766019749494, -232076588108, -186657842368, 782149580004, -941109414814, 147762360112], [-24779479759739634, 159135765377086, 5350452601180, -17831744948053, 289383367650, -2445894831816, -448913943838, -193816040509, 608508148069, 1356854289007, -16610909421, 171626774079, -934538276917, 221740150871], [-8918908599562250, 145989758007180, 2656844735628, -8801240160971, -1389972182036, 160131884960, -35732798224, -399441266834, 391689832646, 788767062406, 649336762938, -566273602858, 1880600610338, 309230699158], [-10171904978784370, -263231290777014, -1056921475250, -27001325876350, -350362685966, -886765816416, 945969069174, 529618192368, -383675407152, 829059020550, 394127143622, -60722100110, 241348333556, 64890716940], [3081433996992281, -53153257334846, 5130726364604, 3459756330847, 284890621842, 191006695353, 640569499814, 8358222054, -1375022475783, 97664136772, -39934835950, 397962063704, -662192526035, 239150960034], [-12631150110586314, 127520241033848, 8416481781130, -34808869339722, 306651437458, -2676748898426, 163639962420, 360015561218, -951006059336, 342037443340, -360128381620, 184208261836, -560941027142, -310318751022], [-6793852082587712, -5091680494731, 11072124985595, -214378580513, -1644335939312, 258593317839, -1126872616458, 680474003646, -257904029328, 1809761450484, 54136570368, -841777864334, -213717485804, 95448636742], [-5424278333001765, -109306686840175, 7892421076385, -54587583554030, -824467878296, -933082341076, 265311036344, -155012716702, 1593413243419, 2167231952362, -306050478256, -816020782358, 1664277274735, 226299059594], [4763543489618945, -227875946845319, 7658835033467, -57310740390533, 719084504841, 272083876114, -207772376168, -1032007192169, 309209844857, -94685774801, -406606897008, 902006543614, 467558287654, 382533638807], [-9729774630858967, -345792743899643, 2931032940833, 47449854333812, -633752216334, -5857220566028, 420283448694, -595070342782, 249210022309, -581544176856, 577068447230, -195706407524, 132247303737, 114686713902], [-24514521802950829, -16520688234609, -2193035328449, -23978097420341, 58310350371, 171017377632, 763187932308, 207961445198, 1487765399152, -35444867384, -252640794961, -150008326095, 1636044532593, -18695923954], [4008609910722613, 140294407207242, -8072559009542, -32602999724438, -50880529553, -63458495582, -751341596216, -623697265671, 1000711297440, -1533311850311, -1173154531367, -1733602472178, 1071640256622, -136388675509], [-4652832678743398, 558953189173980, -3615392683222, -25521600163949, 478827090920, 476178184880, 2636863770110, 696537285830, 689030651332, -1016463473390, -245590644396, -533851708546, 1887361824004, 375895668502], [12359300683318209, 288781825009927, 1856536920457, 6681917482462, 197172305617, 3699697628042, -253626929244, 294443508239, -30950847065, 566299132991, -187354118538, -162541217586, 1277184693642, -68357739117], [-10855018159356666, 277341305392834, -10396230650150, -55708903571684, -917757048402, -804803058460, 143564692416, -443311898586, -2051851877550, -633794067202, 464268353730, 1809993617248, -2168475739170, 140604143338], [2845304232289671, -336698755502965, -8976388912647, 24280196198493, -242733376473, -2962368246078, -2080629220, 1135235153797, 1765716996059, 538651775905, 367504433728, 31396170502, -290105403834, 75628358869], [8564847414576532, 178434474707548, -3833878712752, -23869803968690, 695140711474, 3262618511680, 393469770686, 310322066352, -987520710, -1171909971378, -105933300654, -263569461206, -481115896226, 338273784156], [7895082491757508, -260115609416138, 15833240983460, 49791859566060, 937804914742, -1756326610020, 2112055971584, 1833062221056, -207419602182, -667120069530, 743356549958, -322881537110, -204737534692, 1012317816944], [7813243788193172, 286393575838606, -2025781544538, -36004642956364, -1074112709120, -4453593376756, -1543519600808, -412179780076, -894650729138, 1537287973556, -308853777892, -1504885497852, -2212155781718, 799046723388], [1050002803825375, 13277036286224, 1349905615612, 2266072235460, -98159759223, 1313163218420, -1127514979376, 502036472427, -1482863175480, 29873388323, -280385010001, 1432996377478, 120699904414, 285896617585], [20907182447416898, -103055274321316, -4147259746406, 59858370603414, -2146275627882, 4430049328386, -486726606524, -36539999940, -321989974326, -1738824190894, 655042968038, -1254658500986, -41896693268, 304207172236], [-37224928549917593, -377184235762315, -3244766626757, 3464561391202, -432899801086, -1492235176152, 2373767624964, 1047778521206, -487891114037, -1898399338880, -118683571166, -387475755412, -1224838349199, 997937017974], [8797761237307675, 7683137043475, -4624636667597, -75868941027347, -571075648061, 3353056678848, 293964667468, 251709107076, 1406937932394, -392504109218, 413693218897, -64847902269, 1162346509959, 118201777508], [28636665289852039, -261485175298813, -8874581728405, 17311385365380, 1172983367612, -5102490759746, 377816582212, 1763143080926, 910856967247, -481127455138, 1538072444504, 1578788143498, -195275262085, 40444219534], [-15186958697877721, 1323939601531885, -1509160166551, 74412878318706, -561153657682, 6432417522478, 5586263778, -543622476478, -872631237677, 985166252784, 7253192162, -1648210124520, 1487506561307, 335637930638], [-710259118088581, -244734826418105, -3870400352647, -83713250285475, 614948190367, -1818412335662, -157709302184, 65900995085, 1693204462339, 3415671729561, -38705964356, 1247227208606, 1509366826238, -429061537763], [-46924961798902756, -493890033328819, -646839361625, -58580703906121, 3661001174936, 4471833788307, 144661598718, 1187906276798, 147062390080, -445091419072, 1312186735232, 2365706592994, -2034849087892, 632229023526], [87395814727997474, 647663995100686, 14801988316066, 9618225209251, 722055671862, -7497286846040, -488449178148, 1122349821495, 3204059963583, -704675649861, -1311571399095, 213786863427, 1167814070757, -439234565877], [-2500407049232290, -177044543254150, -3090998308034, -19563934729320, 1205755713178, -3790521799300, 1076039789024, 1226862437702, -2890959130574, -3435019626666, 919893457784, 2567129733740, -392582030708, -1024854545322], [-3527544736500795, 2020754048146, 8713679249444, 31908337510499, 2266333799412, 726252389387, -109113756952, 563715494270, 2206219325917, 4125983000686, -2174589038620, -328513985118, 2227922221581, -389912256746], [16968499470636031, 194423928009429, 5424720008613, -4533234374974, -4510967232405, -5813800450722, -898418779530, -1628196050877, -2010151159119, -1079190497353, -205683624094, -1598419508864, -4113992940590, 950792549439], [14015433610743267, -238206160872877, 27764130080617, -91004209413934, 936523226566, -2628086352194, -987173193458, -771165791268, -1892980565271, -1881928354464, 1268859165482, 1414380113554, 915318843851, 477132133804], [-20771814981854370, -232391882178556, 11965363369516, 2770491279556, -613590485820, -1930925251300, -2013816904800, -2674931616552, 163455571956, 3311045796888, 127995478992, -883597406148, 1953346212228, 1159439741616], [72195791938893811, 754145707046105, -4749709722481, 12679285521198, 835692510589, 2932337788640, 1299627187238, 1721435094150, 242556373566, -2045827922180, 1461311268347, -1560901810785, 1055510732489, -33521366474], [22101420771766683, 196007665321433, -5760364637431, -6245324516092, -426019340725, 1400312344758, -3095503154394, -3893796753551, -864560690485, 749520485509, -1208028924552, 2858429952138, -3889741521252, -497616546651], [-28200816601448863, 573213102735255, -2108762046751, -53702540192285, -1821480053739, 3283954970816, 2318945648066, -2011138056051, -1971792067569, -2703712228193, -59224775116, 1276684718300, -1142570114780, 347504785173], [36318177276740657, 49479753255256, -1269117021626, 121403320148173, -2581404842648, -5101477100087, 1042089819312, -579987117142, 1448034163741, -450134556118, 5354209848, -840553521510, 3443748137925, 44283715482], [20872344034892304, -668055078026348, 859257208528, -146380018196908, 2102295573332, -8926790783164, -2721658783012, 537185610048, -2137315337184, -277219334968, -1325150030808, 3692724520716, -4415230423420, 367561564928], [-110990293071828538, -233157547340380, -27115315104706, 18460588111824, 1823191708070, -452406488360, -153773138088, -735880562288, -371426814544, 6200569998810, -1160930903030, 933021555850, 254795714546, -1076346049936], [-66854978415521360, -98134210652530, 8446018301772, -10208123304112, -2417629950912, 8640835395770, 2405341473856, -923418880424, -3426673465750, 978697191486, 935405863752, -180762606532, 326651706070, 1559447974848], [37820707902818648, -319499127523868, 20728418976994, 31823909156842, -4001113803258, -4308832112486, -1217070800488, -2127516213228, 1455086500194, 3427731042958, -3192901157922, -1475955316738, 12759857256, -1665905270132], [-548065189355651, -1626981229705943, -2931432138717, -157172546846382, 729327296372, -2359393986036, -3377029610316, -1719343781712, -126333190461, 4845943496430, 1233206969048, 819700707260, 4024523315937, -222990412172], [46062344867006739, -709106518751663, -36368993964065, -34768293753337, -2556228755721, -207074870826, -3103112191028, 411048731614, -1898099367370, 555842838550, 875226227771, -1739928468455, -2380529153761, 1972636479622], [-68573473707423310, -522543082710292, 5946980642384, 174057881411136, 5260158806532, 3938913566180, -1983076447528, 2737926128836, -2145527298796, -3190369347048, 4384260416, 4695350363528, -2053090265368, 556050436836], [-11378982500584398, 1439279477866402, -39788962371678, -139342030161145, -608531766306, -1682113277664, 3724293109472, -1563665869115, -827700470539, 2017953656201, 2128429927179, -716621211843, 2344694588851, -1602622792159], [-45412072479662342, 203600332304330, -15467264106682, 40148083260838, 1391482892942, -314850398488, 3308303079452, 1113219893696, 1778456020996, 5723273404300, -877298885382, 6778780807742, -4804625403710, 1184740505752], [4083671206577062, 121676061146888, 7698138586948, -16713654066630, -632206650794, -126572318482, 387585123120, -1176283945018, 4526843665582, 2635637399742, 1130460078326, -2763259475848, -1963338739850, 1381070876770], [56560686173128582, -1035592600207206, -4135419509198, 165846831306382, -1436079036524, -5182741626234, 2426515194708, 1248795227964, 894780784944, 1821356468140, 404308975444, -703129542864, 3875028135348, 4105784422060], [-24218983522146941, -992751643137487, 48029341766315, -212853241870055, 3878778088967, 11714486393848, -3782133789442, 390802867987, 1379541522905, -115077030403, -821511511564, 3201457258808, 965649717580, -1510657264797], [-34612660656147488, 913828289135068, -15425918709224, 2535528482743, -87933407732, -5778485615768, -1675189847376, -5279364556593, 3004144474467, 6895824947675, -766405621493, 823547911193, 3121637833215, -925678119333], [18029018896340475, 324117730879847, 7402697973833, -212661025461633, -3990350107893, -5933619658256, -2968171554758, -2410843282132, 2356477683796, 206781979798, -2822060985045, -5337199677393, -2799860646595, -59689153460], [69511652322707368, -645735940023064, 22077575890032, -251974246480086, -2470533020672, -6089026148534, 4345134253232, 1388152351088, -2023870670678, -5345306004092, 4341022045044, 1673717946160, -256886167350, 776717058624], [55692313555959124, 1239926657042688, 29839031951272, 126194235833468, 4910751982972, -12399815077904, 4096389209268, 4011279664890, 687290167998, -7055678817826, -1098882609754, -1920323360662, -1506829487434, -510445876982], [5680209686598823, 201459920725417, 48127802969903, -241758332974619, 1320245623143, -3354102259892, -775104610134, -1295071455731, -307083408829, 918521478247, 937209628002, -1696168527650, -4860891362234, -1304994964139], [-38709068128055776, 425319334786734, 59601535746424, 188369244329610, 9010267251472, -7946632078410, -972434258896, 7985990110906, 636939556076, -5922674348752, 842477312584, -2679091402574, 4310853213694, -77812363778], [46771006683370424, -1006361840860300, -10037469139560, -132086514762742, -8955526639728, -9745775138636, -2188149770764, -1632181099370, -363964234678, -183908248634, -220764788502, -7963168999958, 6035598991834, -1497525589794], [-199736362562387027, -716009200902109, -834562584153, -38788010600733, -1987379666567, 7766064411216, -5937675894800, -884248299589, 1713901230379, 3009303949941, -395029409580, 3684053137766, -1309933063020, 366726709107], [-15017540200457655, -159271932730093, -1022808416647, 36462019451920, -291345169658, 720967807548, 4511435169106, -727179604436, -1875869154841, 8651952452344, -4105125423890, 7111688762162, -3915693967115, 33464307460], [-23544602201864963, 1190543931395553, 2191163493009, -24022240132354, 3625200267086, -22995816594388, 1621084526620, 3300737818088, 97734619279, -1428745545892, -4670485606338, 1692139167994, -3495144920021, -2252565927028], [160010167060175189, 665645214899709, 3805185115387, -135980213956567, 1938985616957, -6375045368692, -1937944761182, 4219820821702, -891550687930, 5777953189744, -758456739761, -122956732689, -2595580849999, 301485203270], [-95035318313077169, -51981235238115, -3774354786595, -232226374180588, -424381998363, 21699961899040, 2415077505936, -2156999685732, 2919737168574, -7466035749226, 3054418148739, 1688994692821, -2138433453279, 1306844596732], [51155885216014921, 109928553701411, 21804092965781, -7806026171268, 2281769460477, 20860830022406, 4786239865752, -601336021839, -879966226323, -1187483109379, 3993098130712, -2417632449104, -1774821438772, 906144530045], [59022777328786850, 207789601611184, 27524758298150, 18589667400704, 6199805592010, 14413629249618, 589801150708, 7574013142634, 128232907672, -6890153951296, -208560610416, 7315222178004, -242198101290, 2336265356434], [-91904252619953740, 371973393860986, -4453885603256, 189083888168686, -3713533150016, 560399129366, -1851208159540, -1895565872318, 1733862052460, 3159275023108, -3634861530346, -7972481365078, -1232533851192, -3819669867966], [47856728142707856, -335092595645486, -20533859989540, 36101346086034, 730571413340, 11552928273878, 5725022145596, 5315723723610, 3649575555084, -8611194290604, -4738944357828, -6616120753618, 1348979459246, -4561857586442], [117522713719994902, -1277979104846586, -73704395027598, 396213717491350, -5336061352038, -53925511768, -6238845616102, -4651933592476, -3317305178744, 1389440792558, -1305337099122, 629512702502, -3916548472132, -1349691167504], [22392556669087744, 1756503854007320, -41519731246972, -30638679667606, -578325877212, 10412167219756, 16635499134048, 3498848058242, 1212310742830, -9406349394666, 2122826290334, -3680511393038, 2662947426018, -1669801074342], [-30805820894749695, -633141037223309, -12988352435015, -108261967120957, -530971872959, 42362752552162, -8158893050464, -7111823549140, -4722750763916, 1638866915084, -3087073544921, 3085296856581, 250176710063, -967837689564], [-15091980846804611, -1710911789689181, -17598792647329, -370767804844873, -1440944452951, 11896730824830, 9995535342378, 3692671808680, -13575544115386, -2448316257256, 2415157266885, -2185903161211, 549815747457, 570427406744], [82399991403835984, 979964887327424, 26346747421428, 17682797312362, -3855583690284, -24820817932092, 4427512311992, 4730362894314, 2734651758078, 2289600216966, 5260804645378, -5742621682566, -118742838106, 2722451678970], [-114725266155856632, -3624094812424972, 11065954465378, 33560226751529, 2937203187352, -9196594824004, -10021585515642, -4273204559169, -6837376666287, 5324161446923, -3312739036219, -1741329089695, -2764887946927, -2495071318157], [123018523281202967, -1214567018728883, 41355648267449, -134569970328718, 2219013186832, 9004236246408, 7630280476944, 5186560030238, 15805135040011, 1676381163906, -694787327112, -5806045287778, 17563134636651, -559257927634], [-27798391033035081, 2616855723522812, -6638064088374, 69710871090571, 1995001873016, 6079752493459, 2980439492844, 3614556873714, 5747695240851, -11458882459526, -1766831995332, 2314045302274, -9866035410649, 325866639946], [-87150587594874963, -3779294945967425, -74495572110253, -36809128172676, 1112879222879, 6387446342616, 4498795262892, 606418998060, -5567061958914, 5309473437658, -6000560344683, 3389410324975, 686318524319, 2202607725868], [116843188051408434, -371541354242898, -21140944130934, -150139271532418, 2321675035172, 2715562821530, -674985499932, -4427456863228, -1861597102244, 8316953957088, -33575550480, 9318374057472, -6571432199828, 1576203454620], [91380371318962325, -687026154879111, 46205514745429, 125562410576134, 576245656090, -972703766188, -6027193516416, -8698782245716, -1227239477933, 4701939504104, 179766298290, -4897516501350, -4181655618525, 813289284336], [52701124069323210, 2359890259064488, 38028210361490, -114014258446622, 9269217994234, 4577427145798, 7716301394064, -2984962157764, 13356126687394, 3891566014250, 2030090783606, 1618684507170, 14853550004464, 1644627110492], [35728591920751399, 1252930051835281, 85025218578495, 99858942514822, -8675484397966, -21052495920372, -2644612888220, -1211721812786, 2547555913787, -1412239411528, 4557621387442, -2808524509564, -4665425914327, -225131827202], [90256588351585530, 1285310416541156, 14946333739146, 128705714981023, -10971443006684, -10372188107756, -5828023179134, -1818248111748, -8220288387702, 4426190014668, 2836359794426, -2379984569012, -2226487460242, -3102606881900], [151108831234731640, -3705668696320470, 38739970741654, 371232105418960, 5830127185856, 83604383168, -12440741083672, 8811028547068, -10799622733246, 2033947494296, 734469043608, -251823656860, -8603074476006, 242673329164], [-118530166697280569, -4377029369455154, 27926028865838, 89959804463648, 1542175945109, -9934785793246, 19339492262, 793635554209, 306274667330, -14214304124773, -6536300560713, -9248257634260, -3514083039864, 1233524342095], [-240194010039517117, 471050756274893, -49911832866037, 250425727394433, -4900080185841, 12249044253568, 14144864309518, 5538894983775, 1767978798429, 2580929112221, 3333338008276, -3165968332436, 6832920469844, 54412813671], [72471074376394285, -646967617963433, -101154126466007, 99158066477822, -12490011989827, 4412595501574, -15273033623268, -10654922517815, -9142738389799, -11082116749047, 1679285032480, -9612380401304, -2409971737612, -1325674033843], [-9819383308091364, -944533586328482, 44603844121778, 293205008432664, -7548921694188, -6702703974840, 9547273086636, 2723214725468, -17436417629126, -18715364004748, 2453581152864, -2763002269144, -11643656293522, 2941494901436], [31567580267488029, 1727150117399747, -93520989332841, 307824634263260, -4567660633330, 34677507366230, 1105389736768, -1534465902156, 8078774690859, 22462675581644, -1380681620690, 2968743412350, 2940985710991, -343695132568], [94312027505005227, 2014286141117657, -1993393341297, -83382515911848, -10033060637706, 16029760329512, 2570537649730, 14262533580056, -8919212593955, 2809090185324, 4371756195902, -988975653650, 5093525421963, 1127341571632], [52186744263319719, -5994673793171679, 18543536044973, -58354144601732, -68418135505, 2450525877670, -10540594180626, 5477875192145, 8623276446043, 14540969711249, 3477836906136, -5362117496234, 11348359040836, 255514073869], [-96525784789441590, -2961056160683856, -93527775337282, 145999156119556, -14807339050282, 23502078091952, 920920253024, -9033264367956, -7124693630532, 7809720242586, 699182626582, 6688181660870, -956360390858, -3898724130964], [171962541717814877, -3425483455862475, -13938282288959, 4747860862794, 11421237558288, -42008864321490, 10384129321290, 2045501665276, 3103590826463, -9075677689550, 7685946243480, 4626215286688, 7608996349519, -3969706649300], [-44226735877863579, 2443612237726969, -148701042665641, -75701017303761, -5972307272947, 25795028778778, 9582260722068, 204030810549, -14043429788793, -9351263460859, 3892206318762, 14917300010148, -14586944388340, 3955283380197], [33593419418987802, 450257732038845, -51309792204869, 892220333770261, 4805465717872, 26296738339441, -7548714891382, -5132777494262, -6253141230706, -5037693871080, -3627911083888, 4116209289846, -16363779822858, 4517316265210], [213140061584591376, -4277787678375363, -39005620953505, 475880243934650, 8869366044235, 12837467617424, 8389792149656, 5408020398633, -3734665494969, -5681671213361, -5815621413179, 5099278758426, -5932957044069, -4806870639057], [139801972568416692, 4825545528826836, 33908292137340, -127807965581910, -23986628259584, 19296567378248, 11094436382888, -6449223229754, 7512475752362, 6859786408782, 3954971970578, -11592013093230, -4222271081898, -305194838138], [59647337055368447, -3834997232230170, -64559578121686, -405788747391600, 17872925817121, -17793673795742, 10106154800038, 581802940997, 11499503267158, -6318426236573, -966986929241, 4437642067756, -5154781588312, 2615160209523], [-69104275100696181, -7620945766187527, -27827964025943, -102314154788771, -3037817287193, -26570738913220, -20599679800464, -11379471895455, -6610083323115, -5111310369925, 1255718067040, -1333651957018, -12852924009636, -4825236692103], [-16854631600399080, -1876788465352958, 41458092729316, -437555867937584, 2703417556242, 54261437557076, -12344773626164, -8342197508300, -3326463935638, 2416211899106, 4217963557570, 11006160548394, 9103584156456, -5311128254572], [132784254939979139, 2495295958809909, -99841819137803, 521855016866376, 10067247654753, -22586807338352, 7500943088904, 15270623479618, 7307536478456, 17960779307868, 8671810221981, -6748731718093, 29449701393103, 444847818842], [278243620246785799, -2391864715315533, 75941545844437, 238962600516341, -5059450958025, -5343528151314, -3274710442864, 338016221557, 10876211906027, -11863991261655, -4850494350952, -9839155143442, 10136746520450, 124557433821], [-50058653994128576, 264947642310777, -173520788778125, 564687054642957, 14803082731718, 15148406247861, -16315388947390, 987687234396, 398793528018, -8409980879866, -1476548960174, 7015547386914, 2010553217830, 2364754353600], [40199166917406132, 5420387013332384, -36253979240212, 150475832024952, -5374468425178, 49853814028968, -15818770741352, -8628652200298, -8235219269120, -8308146194830, -4921648757158, -3264383709656, -25076623364032, 7472847129874], [411877290406309103, 4751678066850777, -957260068759, -319876704744127, -16114467050853, 15641031192434, 8796980084434, -9891393554606, -16877453677816, 10122071541546, -14114946224591, 10533065977541, -10278000450147, -8722084352654], [-186353477607203750, 4970919956101240, -81636078931726, 93658204240756, -18984020693130, -25025801072046, -10304224950048, -3089443464814, -91273140176, -2963837221336, 6793741665580, -2162722244320, -4922672447618, 10993994482002], [-198416487426222156, 1891018910694592, 214228295472392, 89224537355766, 11209110387864, -45842800485444, 21696571696696, 16387496968308, 4271539974048, -24290604698244, 11613635280004, -1455961032732, 7962609686672, 1531886578100], [-46306979831764566, -1075161521288812, -23859797936802, 201486972230862, 25709514845214, 15782326167518, -485225127232, 13280326694712, 2005711012422, -19141571835042, 7197435434934, 21738411575562, -23918887696392, 3924908183864], [7125215386710534, 1561507361767726, 21140687231262, -515453229382498, -14817769345054, -126334785547800, 1471841397150, -525874673904, 5247399282192, -10174301085102, -5741976814538, -9398050981462, 2988513884332, 7973819890524], [104058348183674693, 3177596544052801, -129422088055239, 168969192073135, 4526342864889, -7965137794270, 20029547629514, 1926508687315, -13380082643425, 8860968577443, -12363259351198, -2145702245770, -22085524693744, 6892821358131], [-628328839281924899, 5911542730405883, 39539214200557, -211821303952461, -4532994662943, -62294470626160, -15457727104594, -8571462619465, 14501250243265, 16671078637085, -12003743263850, 466262049542, 5590472428954, -3546472734313], [-296557696468158645, -7579575107882679, -23617531744881, -374085896447958, -4639084237896, 37840543046438, 468592044218, 15731184494234, -14232636438809, -13930016207382, 1114200670280, -1787621792162, -6427763142771, 1348916817158], [-229255480670964233, 3170886525271393, -121460122398437, 366972396769154, 7613524563398, -39589666581932, 21036736112224, 239786572306, 5843325885599, 6230714244060, 5918951484790, -10939067186324, 13942413510185, 464876322786], [-425025890407749009, -395920473252839, 233542774989087, -428107106510553, -12578722131725, 32857008874382, 3340190039780, -3250226062330, 7388895547378, -6573188113842, 11991418588731, -4965626523379, -1728606167661, -2678286557210], [167433636917632229, -620085765376998, 194912219358986, -1673571483786860, 22641352969505, 17756027616412, 598785753204, -3093120948861, -2387904426018, 185790779435, -13770341977469, 17207247549606, -4034812517144, -8680586444303], [-269723397358695454, -2337022128325923, -275058551321977, 593796476443337, 13347134272102, 42294170877503, 3975145990424, -6830609247910, -6162827227562, -3030829634406, 1241436744546, -1144367261932, -11032214431242, 3243712192822], [-335984081455095343, 4000042310724917, -62674923492153, 54911336915995, 23735664057941, 33549189924124, 8466775315346, 7242591636616, -9706685731756, -25994882249738, 2567021573509, 26787013944981, -22037844242005, 5566725534792], [-53655773364244815, 4726626141115130, 178752853059018, 110000769192552, 18847031822065, -49755779884128, 543262429268, 4278804842951, 5261760300502, 10431177772903, -6332138272881, 18690045714754, 13708241064192, 17207771397], [-292903977087185708, 761125323959766, -105752102462374, -81342963648163, -416425636414, 67465839603224, -2799583446212, -24003093500922, -2801426437998, -12411113104486, -1694585526664, -13652399744508, 23656833240, 3185716019646], [-133983007605791426, -1951957893171094, -14545190822180, 708409696920522, -3751414792162, -67513795877478, -32901250654464, -17506561504188, 9212900441556, 14663594764354, -20192358320822, -16519932448106, -5340472644038, -16644326720068], [236511724895808796, -3377399758782725, 45273427925333, 641389965218456, 3143944684583, -9698873210918, -18779616986112, -6171410710987, 13979670715543, -1880622660113, -5144840422595, -39078068452702, 21731130617559, -10428057076485], [-294137819190153846, -3087695967440174, 199454825424340, 348696236318361, -2567831554854, -47065095796628, 3078862879170, -1513723216049, 6807002204765, 17479571933503, -11863949072817, -15170858875661, 27658378193659, -1213291660685], [-11778399475123344, 11621683429268657, 99039089923851, 1301824811741550, -1096359126933, -27128948146228, -28744835645984, -18548295852631, 8371578747823, -16020781401321, -6665777151043, 13539672289306, -38584348515981, -1551418736849], [-183033929660965203, -10357429389283517, -173943243429341, -770573674280267, -2189558602431, 61355902152702, 10421675334202, 9606103964608, -15184413068782, 2550877814004, 4369376307049, 18503832891773, 44620653124017, 60459533272], [116109191143632733, -7103789632200887, -143695139914601, -571331892557077, 19657630354729, -38672114771370, -11283847378436, 8614716335433, 9627291659235, -4181924666631, -13409228691106, 11574054053452, -42463232581456, -4721547025055], [-157222852879033937, -3407003077846441, -122630356082013, 365420865060126, -10413464277220, -70317877334390, -37801780643774, -9996411358880, -527592954139, 23385402148086, -9207018959040, -28277500109120, 25957782832221, -966424720888], [-238675403686773126, 1410625833066478, 67419414443346, 697010905393318, 29000691331046, 8263205507284, -34834584435238, -4345700299148, 9802335340112, 24980894035398, -15620012969150, 8452233457042, -21458384139400, 1650478767040], [-158737262461075229, -3741976832851779, 47009341048647, -852542705151579, 7420218033387, 86751999150980, -34048150057534, -16227297673717, -1426887717971, 2230919078513, -15835481858140, -15461834600188, 19573925530788, -1308300401349], [318083660698278037, 24178217986891, 60775591586979, 65870710863154, 15541510429897, 44485094949958, -7715526959590, -13648128734361, 7210271201241, -23468890191933, 2772468853664, 20035037292898, -56646845088448, -1499368459621], [721000480897866857, -7311547834318791, -75482010716009, -655331526709913, 824850544925, 90106139390438, -25766424035320, 11036495071493, -4240025277629, 22213208678713, 5738985284062, 2999351013332, 10182274998120, -6340712331931], [-312233297549274641, -2959820568452404, -334719898687422, -550049986683881, -40909467614486, 69054279703241, -36608909217278, -29579718392942, -14194627940749, 24281220412688, 8140010460666, -6996377730236, 2463529484915, -9826444675786], [-154682421961675862, 1117190366909464, -224116891661562, 983879966540713, -16908381196808, 98467647168236, 10310817652946, -24695809092316, 17708006982346, -28787662700924, 3358041249526, -9584530590920, 26684634939074, 1766626464268], [-27148692741000266, 6510525209623331, 80830182717637, -588892188514010, 22563060706837, -110314587236278, 19388685629170, -57814077363, -7525046481459, 13897020394013, -12571031784317, 31306423039160, 10752367220601, -3122907078713], [546582853903064145, 4819710267717937, 299457158379949, -1688428404220931, 37927363593213, -29409264824540, 4479478325736, -11344272803444, 15461044652306, 37742281856482, -7891057832729, 41907275459029, 24218109047145, -2231369407948], [-107442338990399608, 1387821870708049, 116508791670151, 445190441972595, 18758821179188, 36665102897019, 62271509362914, 3146546895990, -55417734732, -10939762314368, -10465223685944, 31047405689182, 38407657658044, -6815566713538], [59299244551493095, 5427826077484185, 465847207118083, 478898762810437, -17755509843093, -14534397339706, -7855073057052, 14949326726998, 2034834808622, -49855958802670, 5185863803023, -12292003195923, 7415605035915, 14187663702862], [266141650519870739, -562512293782005, 82055711038467, 1158783160070800, 4922577726376, -48773182944270, 10059827085880, 16585987570006, -28570988753569, -31403772179358, -6810566617272, 57999209128494, -92921575529017, -2211860865146], [719647246187854030, 3305825856154866, -112912957122114, -1201248764809846, 450619407222, 45641671303304, 24768822938206, 39713731967884, -5147159487832, -30702215034110, 26730466025106, -24733669449782, 46597902410428, 6223738101872], [-6901903173797143, 3188614693977757, -24818063951365, 1073910713819935, 16017328545781, 69400059288488, 23779399528250, -3800686677796, 8067333494992, -55225591354002, -3150186945175, 15587548501097, -2715453795281, 17324486701212], [-330465269923194785, 13206775831770827, 130430796910727, 557441714189803, 21899189525055, -56404385428144, -21378245411320, -6457536020268, 27516234950754, 39272016028038, -4385190894715, -5579320920345, 27733216032991, -5637842846804], [220477112025744141, -12216741314745828, -6633598365780, 235332297590982, -2330453468027, -89708286797130, 29943301107704, -17076869648729, 4053222294842, 36900000060639, 862068097655, -38874120415122, 32023029624360, -2515611151259], [651706247860803871, 6086152470189531, 185090869259125, -1150901434007727, -2928456377381, -54381001308866, -49680391890340, -17816822625273, -22828300920831, 24382738983135, -21258900678630, -11121788359016, -35426660799908, 5381127986391], [-461451712441466790, -15429428347846, -680591079034810, -36633129582244, 13224509467714, -34850546280516, -9842579105764, -2672908427464, 17104655022004, 10181405277116, -15172918173462, -11083370949558, 10865635810122, -8868179641576], [-12840165228846071, 10060133846973342, 161521828336884, 56037253058097, -7745654894144, 118722232547963, 15843777491126, -17272629595920, -11091327992613, 20032403796070, 30842804804968, 51655707097140, 15331801109955, 1804916798160], [-183535567888683, -8446213986143791, -224903480084203, 624872893831560, 24871490785054, -24458294821068, -27500654781274, -1412391129442, 45792887614609, -29409285396348, -12405342691010, 8500675076444, -20718519623623, -532370059270], [699000593545519992, -3637178931990706, 244529345901418, 826190335657965, 30093534947086, -71541227903208, 38787121631904, -10748335722246, 17372385915474, -33614436074238, -16658659815744, 28891370983132, 33014714336776, -3206904398054], [-210254303194000479, -14761379609548728, -213578627721078, -1162870183069475, -30155149549132, -11391726215639, -11671162111040, 313682668786, -2881215338371, 22414361828326, 11137173295780, -15613809154554, 2785653022025, -6793659769918], [-212179618281786414, 5053614820465648, -158880036195784, 242372776951816, -4007951562648, -31729422212656, 51631178317556, 2912836094592, -4299445501776, 86496848683692, 6507464524256, 1889694518328, 18234421937620, -3543957736424], [-268149406897948129, 5830701152266021, 6680548344817, -485991042815882, -9574617942759, -64388893782236, 7022283800920, 17332123640384, 35139541739494, -30579240316682, -7951755249733, -37789985583411, 75786782375613, -5316454730304], [-518689481594159675, -5918255421331524, 172353449208628, 148322867386874, 18553426440665, 50946187653954, 13561324408632, -25709712970573, 13465828479022, 51060782946907, 5427194548571, -11317576352794, 17460059267732, 11458608531145], [-96242981897822053, -5779872338085093, -21521529048907, 1615696381584866, -26004486843698, 91379015474162, -11779079036622, -19972068158644, -45657363102167, -26402711501304, 16439735790906, -64855919076142, 21587910171519, -103129792972], [146262904287936748, 12014379821215548, -240173606342436, -461983357145066, 3520605503864, -84309655265524, 9469099825328, -47838176031126, 31485425569530, 27372363654458, -5006296267986, 29640747521478, -39381461453074, -5078394890374], [413437076347664082, 3674477924287428, -166376119266606, 426310853765078, -28149290256862, 78595356861870, -38535786880568, 13356852073220, -68603704166942, 30048159134870, 11038118422158, -9208913780006, 5038611488296, -10688006826748], [-424043858224297114, 26104564677458726, -264196038734208, -870307784373517, -3558425137730, 18303834514456, -3560696967774, -3696244478363, 864858801311, -47479950533627, -14147520466259, -4307219815399, -7883153777939, -30812422832103], [-188274837008625512, 16840128376600791, 53798247200401, -1866587228765635, -13857008262648, -124843387485707, -57271679687970, -27713994562590, 9375075909624, 19188746060600, -7197127606304, -48555273201290, -27827402546296, 20991995758130], [192202692076599338, -19826987660465060, 51384113570914, -1906273239889584, -11144803531730, 36918003125780, 19273490454408, -23016368785788, -2126270067564, 81483841124106, -36517067890218, -4089216600698, 10328045960446, 29314899715828], [665569055735209204, 8907835365459801, -221039423656737, -2164942023274420, -12747303944189, 148998595729196, 14044899013054, -17868559544481, -25525273622751, -54895953588725, -33873883328211, 48646870152276, -84028905889595, 7012921385173], [-104305681538738302, -1157596917720532, -18240530923490, -1786082560795710, -5444472713518, 90006901113362, -3968532394788, -27185338080500, -8945586159694, 23716510649422, 41304682721666, 35653868155098, -60397641048344, 23028693609788], [288080440342322563, -577053878433513, -42465489268665, 877551743849849, -72615902209209, 81864290190830, 21637721404414, -36092161668263, 9654460518989, 64281611885481, -15511129280166, -46857996228514, 4573043273140, 7083810902553], [530491665949577107, 782859846958993, -481202010787061, 1764136258886726, 14456570007635, 45266946753278, -34936728648368, 30840240159847, -39012019688617, -56314858342289, 17649925526776, 18453632928816, -40412235757120, -8517979902805], [914971450729185818, 1414296191987962, 70392769826770, 2051674403262998, -24411715249450, -9715587299208, -14459646898972, -19511291973336, -23032864702632, -2728132423072, 24266182893594, 2396347758774, 25249935491678, 9178580303456], [481004978384628034, -11767651706119936, 187480618588424, -4378378951179608, 42217937903424, -8477614063804, -2075266640572, 16142322897336, -49303994969148, -1889088219948, 8692287087788, 84618144551592, -59289193149500, 15130942360360], [280763735250802840, -4002262459379224, 331034564877110, -52222371208238, 22987946459862, 23619450398414, 39336560661008, 10747900755860, 30277458596458, 43209555509150, 11529092622214, 28849399164638, 28065300293632, -15830099288404], [8925341987344888, 20500071630986822, 346988316133198, -3257370796371086, 32597646276030, -55424037950226, 1442457365812, 42504313215058, 23138136732764, -13560344538766, 1863956558110, -22128298224060, 4527695508432, -23042997332170], [154607471936352036, -23388895439157852, -163445298730140, -58850234467084, 16238159220192, 316069758036, 4518072829496, 23522752184550, 8709911289486, 54542239120398, 6367662239162, -29807631292734, -329861762486, -4069932517658], [212358363181558663, 17398819538879063, 54152866695585, -2600332387433436, -38035914523858, -37711552459750, 12995120462272, 44558608338406, -6073557420913, -10808690964940, 9396062673666, -10036697514520, 50286159728601, -14179116802890], [226243837255296016, -7878761318055920, 508782955541328, -605245569762826, -23227715586294, 8456749649968, 25878329216090, -506538728284, -54330617997218, -35018596073286, -1243059599102, 103213336185430, -82752305936102, 4066250502256], [467006030232359795, -4118572930270479, -78773842271819, -1008212411676056, 7394506867878, -33784653649474, -26954524063096, 36756272597688, 6664742613477, 61101973287016, -68154596774010, -8998340003542, 64783130207289, -7298511314276], [86672596737726562, -12652552736753012, 478240237286326, 521447391457182, 18577079345466, -57365045039074, 26129918881080, -21182958194970, -52669351949448, -30615211435596, 3594813163796, -32241997839408, 48622601905738, 1045930191398], [1288799107320047100, -15592556099580346, 253474502005898, -685649168458680, -35286284188152, 29383011186256, -31117982565772, 38788863380412, -2282402436162, -46576193880372, 43245780777904, -53242127457300, -8872482256366, 38502765206964], [-339257689958903561, 1613951551994073, 816142076565589, -2116965286301212, 29584432690219, -53901914457518, 79644784046106, 11346061438179, 16068786412797, -95320950933593, 4988172613370, -25793331528696, 27987626316626, -3423404065945], [508273592723534823, -33050026697869261, 397943756835085, 606360532534972, -1186880513094, -180895192300782, -38928486675484, 7188628068486, 54689513605551, -29382851238320, -31115877748602, -39163677943516, 6318412090641, -25115764774082], [494363302425038211, -1264892898478829, 916527601470195, 1082836879567637, 11806643175643, 175353534083526, 66997423401762, 23720122505213, -74265989776775, -41954538380007, -23685586835878, -4054179017842, -21513274453760, -1283223927467], [2282002043618916176, -3668422603067372, 452477971034538, -3629885811510475, -3137028686308, 46922049191920, -61371264797270, 21941401756533, -11670073992393, 30660783753893, -7768719592301, 17705652023031, -48837706900829, 25446654672209], [-863204465183961542, -19871660519565614, -167552657015880, -208792370329552, 45744294328272, 101690593514012, 57981688883380, 10605539444050, -50339286685438, 35528402425924, -23088460961028, 55752003482866, 12658554978760, 2363792107406], [-418408583944563557, -2856978613032263, -295532343651167, -1256860436658339, 10309416264327, -226305274643850, -30563809308214, -26142887081256, 52858201397718, 96371493993416, 48676496937815, -23110238264333, 68449054387795, 3704776079624], [-812793065621419224, -2331838527245128, 704294688007904, 588586671970030, -22817953175390, -123407770854612, 10605376421062, -7887074561284, 68279770327930, 37261134415542, -51368247164794, 19438281048086, 124594771585606, -34367071194616], [388653383346711204, 7890322283384150, -345871830369870, -2214148854440902, -6321056355086, -156693683345550, 102264426881312, 40717405955910, 36891085685604, -56962697746634, 34786872894618, -68161645063668, 66404368998724, -47264937548086], [-726460107664608483, -39416827832452165, -846612149965411, -84110058494417, 27309510864257, 166469944644482, 10723320911092, -10715661363324, -86804404413528, -73582804997612, -13267957440869, 16541463491605, -44321741037893, -26927723266212], [-1723397658013060463, 40718841547719237, -24267644319821, -3031440604380796, -474594098886, -23483230426562, 3056639697452, 29609374422662, 43589824149409, 8085876305172, 41463986511222, -107187091416524, 92273412882791, 18641384415654], [-2332818776943508773, 1222343524896529, 36400452559535, 1703713523560226, -27177898626540, -958804208258, -35998348659726, -35389374302534, 41750099563643, -60359268450334, -21098639587268, -27197380143798, 47218313183301, -10820877141914], [133471387716684979, 1990413393086589, -329635937536051, -1091014405978448, 40004740221169, 57028989810092, 79117285030192, 6188883514746, 27428209413684, -105623732443540, 26769799799553, -44226287457253, 94338679973479, -7806720578214], [858477515781607203, -7154874192900937, 426523520687889, 2657039087602279, 24827165288331, -93366028418380, -63848483619714, -9618968773120, -4063718240492, 73137877286550, 46276709759763, -70103367846581, 35356063770365, -23588603552960], [239463508681378617, -8876445743868041, -616427657571243, -4080498497606688, -35777672481642, -255548264242448, -41886050906146, -28397268410024, -32282718020797, -50205310398024, -26679175407722, 1612218954614, 28269434272665, 9382054553216], [54353331551791790, -23151124515747636, 168456384484046, -1952609269821560, 13303938717658, -190665147032482, 28472526193260, 7006910369782, 52031322708800, 92762963376880, 6019550308252, -5658130342672, -50399241865730, 4617792999438], [-2585960892732066032, -12592154282490407, 770634991648615, 2438826235671273, 55574406722538, -23620373719455, -3410806349658, 8108269607460, 62291628492342, 23311602873038, 32468327087438, -19635410826266, 10790086470106, -6242882961936], [968309935959077579, -11271588201967186, 389512473519486, 1608692733835854, 40772354269783, -28826685233692, -41580142252686, -13917475343913, 96394970746020, -4828215824143, -61917643042511, 44211152535272, -108707794308918, 22122188530281], [-1537927438425933342, 23737764515890282, 132924528282364, -795033957140985, -16507119788490, 117899466874004, -127630620442946, -43859714023329, 22757649133113, 52435674710723, -67240186608517, -61622150761697, -56831722833977, -18656827846757], [1348319493287838532, 17997643651719430, 227113262047060, 1417404631133466, 37851946056988, -392413055477850, 61558656531236, -12458438734716, -56215142631738, -45957780124058, -3445101368316, 68482668779052, -38589983232698, 4298700008876], [247479337881116097, 9512817633201811, -316648060488321, -2639496328041346, 15342847274673, -62717931568334, -93327417968470, -35017924883801, 44725249330625, 108708921207191, -33704896312920, -31516489384494, 80106621474256, -18810921958309], [-289129455784178717, -18070309691735537, -374803793482819, -1759581659966892, -12499662636180, 155055900278328, 66722492654986, 9837290590362, -5919555653565, 68643491299918, 22133771253040, 19308401617610, 107418894109049, 18122081400190], [-1276891316892996294, 33935568172374302, 864077488872530, -1127147232219292, -7107994164626, -260657394272320, -19550483721028, -158998395018, -49585710463458, -76527581055002, 14549091998770, 15228144096408, -41894459733954, -4965352797150], [408821189632656274, -2941782033057314, -126848915556950, 2380153155648112, 124379658182970, 256994790568432, -145014305980216, -59878876504006, 10451166512614, 166185953137818, -89843501582944, -53967955367144, 34999541844492, -44198337121630], [-2070816107809756632, 7684881056816124, 223287977880070, 6234678752860988, -72436389075396, 141437229973828, -975556176148, 25683002957490, -109975356605484, -106829593081592, 91195821011440, 34207312572974, -23945971125742, 7007956232150], [3036445959260333432, -12008080784640986, -261577024918616, 2627285299438763, -24685842241374, -161371042988228, 22849473328110, 47889848549452, -34204520926522, 52529475004592, -28325467715800, 28387027082586, -134510608128964, 22942843089716], [314027739620130164, -18225600939385288, 172351901737852, -1319616545026522, 5165219508964, -93630297315840, 56500862036108, 32978377254496, 82376353329752, -11385595488048, 22923583779996, 100950873055980, -119953225067776, 25517429108600], [2399821104424347917, 32405723691635485, 534633637618993, -3208320339733211, 30336060875157, -369246879634112, 94889370674596, -8171221131724, -76964150707070, -36923528935842, -77186152905157, 68233433515477, -44365697326383, -36686784302996], [-541162185350950174, 3350991538593120, -328823446067988, -446260606653744, -31942746830972, -50696432018356, 18892787603672, 27597505764304, -24734806849372, 6216633961636, -36954325098376, -58220340908068, 14303748366444, 40318667930328], [-374985738343558929, -24890178036844185, -937335865726173, 761120083448193, -20000620736857, 226263790239720, -17360482430516, -47132768589438, -10513098925332, -181416839137504, 65255874594815, -57656283892407, -992355886575, 21923056944834], [233617352333780778, -43127134947453289, -835672065347479, -1831827460257353, -18802862013730, -308389314786039, 39349903092948, -57190423937042, 27626389970246, -51450631742730, 14949283791962, -12825644706128, 76843924861870, 11409656159082], [140318758478450049, -15629580508713719, -1404506970524041, 3468694107113775, -40539289299259, 25062473205514, -127452874653912, -49640098379751, -30650009830749, 245510451170429, -53282047059210, 73072323260136, -18010781765596, -37069479604767], [-2035504503032534855, 3932403155089447, -154135187649593, -4391812011350076, 31349925095499, 222632414550936, -97327565307924, 17370388065656, -39564991123262, 33763607503578, -78448516429823, 26049048055591, 43843932162211, -16263311863504], [260274419757372297, -3691134924291491, 1092732982434773, 4552610650391082, 74288847083248, -251383647882514, 30331133021826, 121411892046496, 35769208238495, 123546618816858, 41265719648232, 102320329839348, -83093479361269, 26514878426184], [126611304784934333, 4116187914840088, 1087886737868874, -1402525239873855, 90571964923322, 59835778041771, 97390816350662, 58123172560198, 22869098685689, 20375467199720, 31305433364178, 128704429653320, -123859404116883, -34766589924014], [-857274760596125649, 37693643717573348, 250741873564266, 2911371231594853, 70846531341864, 46570774779159, 13961102589278, -3624055625808, -25116974119635, -135322098230802, 45019809430072, 24760663507860, -192977840488903, -48620476452024], [404160136011161198, -39278723416066622, 490102566657986, -77880354542956, 25101012604750, 78053266451656, 11045933820004, -93457872181630, -1217158725542, -35684229045794, -41990517431490, -12805519127900, 209781575692962, -2846893411186], [1308104165653434327, 1260863214432460, -1234183538902386, -2953285210274405, -56558839507602, 70639230378229, -91776626136426, -163094089142038, -90438027356177, 35973128347888, -45113772030546, 7992435374760, 6432776223143, -28061275266714], [-447616300855030094, 88901163357225858, 404418907275704, 3019529980817105, 44932724722538, -56103624088984, 77232390929438, 56815041642695, 118875283669837, -139938299402521, -63651417569897, 1421152459699, 122246936730423, -58976737927421], [-1392426967399584707, 7273772322283039, -96166323134451, -1884980237573304, -8487647386818, 200994224478420, -3771565568978, 21144346853116, 85486097968619, 11250290437572, -72172054807670, -120706061782006, 186685884283257, 22634786537620], [2175097786182507935, 20825791543755813, -63292943887751, -877629132957025, 52285336226727, -15990011073510, -188001421320666, -173265770942332, -45396128307098, -53212095353676, -2329454343681, 130098090006991, -123182400641389, -1977470579180], [-1215848294415682877, -18149788942231939, 281663814423099, 7438655799109475, 8675685609011, -205083264833778, 113111940292416, -173199673166282, 117619446243182, 264221577402, -24235221850777, -2458302673235, -42274487286929, -31598202173946], [1752464309357358693, -25190511194131545, 734017586264041, -651952196111821, -116798193227107, -53303989263276, 13556190413030, -46088618694147, -27998985505821, 83556356699995, 49349981539128, 86788376467636, -184546455774424, 21456547982565], [3209117073132530674, -42888512658473859, 905547598774503, -5961042427168688, 11675797054267, 33302739640434, -1718490194740, 35789209694977, -51282044571703, -15232130086145, 70060277289465, 100652820952274, -82839945481303, 8032493767471], [756756986948083476, -3286709014160366, -107277588308286, 2283454099589523, -66008993001822, -83670478131808, 85862105339148, -58067175426480, 68701769973060, 147228793069072, 8198159681862, 154136452359338, -123032621084178, -23886985012024], [-2856053214012750301, -50034416782316587, -171257122396669, -1052296863894743, 37250454214379, -84525962699568, -106746790719094, 16521971962873, 183498222078971, 14728194141875, 87253295113262, -170078743758730, 216298961214166, 6295476931545], [-228017951736292514, 47415533892012740, -167760915328956, 232531268395718, 22297203434286, -127365508367726, 77862584778904, 131832415417030, -40542943725262, 15265948182058, 114806178244038, 20005528406824, 13321795919530, 91147916844914], [-337226862822368290, 40535186285435053, 398569558613163, 3913531392956894, -108956450722941, 407453028078102, -18599071748974, -26714509107245, -158835889013749, 168603799904751, -73864284871047, -20011543825744, -52293499043249, -3819517749767], [-54535789019227678, -71365714780738064, -576281641476844, 1870081455972759, 65670233347992, 239986396790460, 120080484571004, 97854006021360, 161975297677536, -8590013067840, 27419395365304, -19754248102704, 53954795219156, 50923255855560], [1031072349619401399, 60169018987922741, 877358750882613, -835168801691662, -28103744935681, -35725148839998, 25701245754338, 63204202543505, -162679672185401, -68018517874775, 40050541657992, 21477331946750, -28411215025844, 17883855752677], [-783534449307711301, -78752227294532371, 253082228685211, 1750389427562500, -26944132739999, -200520029246116, -59129447306370, 56388999324698, -32069144422130, -48714952949880, -114316114646529, 122883248661647, -85461214469895, -32314022006830], [2623093908453337285, 35039476745871658, 140222471169720, -2682364331743805, 68002759059050, 231845391375445, 49979436266050, 137515610337202, 76125048475517, -48977870071624, 15244077560290, -32096646847540, 49659296447969, -20659116795650], [1629902575323107718, -5191278525171138, 1218494032038466, 2425662653131182, -119499228198174, 38592883642224, 44259512254100, 94231539052838, -100567548202862, 81461730808410, -43275513710564, 21986246874292, -11047048458812, 65080015319782], [2394996705174571388, -123393272256782694, 230689214472692, -3606899169617000, 93491425960774, 229597198101128, -84312014099276, -12119347867560, -162440335350042, -31773906995434, -22886309033454, 169129447564250, -182071133710904, -1351243154952], [4456972144740357646, -8221620916363640, -294307395408206, 4765645973600324, -12777201935846, 592120852119222, -22582380776368, 56291047681182, 92201398517172, 85283344263252, -15514526939308, 5102282095336, 155667322404350, -18710829676210], [-326437323564691188, -45228189182638484, -776968708162478, 1614737030114184, -3755165053580, 1189816187180, 195922882274436, 141114352992098, 63103188424696, 53072359372924, -6425484418708, 144276514370302, 40383996736066, -21626879841954], [951966888280084868, -9848028949597618, 386530264811382, -4373187386537656, 122647686316940, -302051325182680, 148592089501380, 93690711779676, -128446980050322, 38540446921952, 31738086005764, 40632865151544, -92069871405914, -18731906581916], [478035982623082758, -12422915671494708, 507761877275844, 201686037000706, 606721454206, -393251443860998, -143736864523240, -1848436186126, 107107507501318, -104748155709106, 24109158187426, -258210606928212, 162213901639166, 34514539540206], [-591231856861129991, -9054725861551093, -423070093728255, -5757068420663773, 25366867996689, 279507309016376, -383279167138114, -143600317435225, 74542487679253, 116686491807985, -16950116418134, 8080354109214, -117438127495862, -64762140206865], [-1668058623405498345, -4822168249951614, -675424377527734, -2147190494530190, -6332553090889, 209906287760236, -44079541618842, -27529477183657, -85475417428376, 104825136385861, -83153438109483, -89629017894856, -26285200657346, 69121265760665], [2361887357820221114, -1819648491039007, 998999797030643, -2209366469825798, 29237617645005, 173359128576764, 165447625299212, 63047364333639, -117357015288417, -240027565238615, 56835132353423, 109603051292318, -136315232814761, 61647567699033], [986663504476431863, 25675751639996425, -29039934887221, -3199991266973091, 188838468287483, -252327548726370, 139745043503884, 92488640256884, 114209146922092, -311418126383104, 87660084138725, -124783642916297, 146630609288921, 83165826141316], [559091306460747546, -7692249793598119, -1102192287378841, -2607593530988565, 81362003730194, 72410599470267, 218314016142022, 34044153146368, 2827869559460, -24945982359346, -54907558125662, 251726314853666, -389537601390004, -74629956500108], [-1178132972341542715, -17094815526816743, -191014887505159, 1433419028938232, 102180694620266, -517345085239444, 183798070771578, -11920128724986, 130278051114057, 25556858611028, 25339360473014, -69027248768280, 77055785324853, 12563350906034], [1103198791350490813, 11386372080369715, 2136970747140547, -264748995206086, 39747329012777, 357128818817198, 218566282433554, 12962911816491, -136165524296427, 94753317695335, -100691437628100, 111772583220574, 81634441183868, -26968178296753], [889095889596056388, 5321237123501816, -474446855550920, 4809059812492832, 81238923387628, 404778901273216, -252986488152696, 15751901511966, 110960692108242, -179529602249370, 1140991389782, -28956767009210, -17114992868470, -131307474196146], [-46006031017221210, 32970099429352934, -1705860090278906, -961795362458494, -234023184672866, 359713139514800, -177363624676286, -216626516183712, 29351051028300, -23868581967138, 13794983382146, 29038712492854, -182707988460544, 72840957432148], [2104828663539281792, 5919583872514231, -1118344194036635, 1307431514932370, 24190581404143, -148596016846978, -184926229059418, 6039767229611, -88321254153863, -393274188384181, -96969363651899, 39409428607692, 10164269342297, 1889690167521], [-3041052907270396047, 11935958190778699, -793194434126593, 6431850075010769, 92454789594713, 679287909881446, -56772078426082, 40742661782698, -146385135063520, 180339895446918, -83386250931081, 65128643073595, 44968125384111, -28824393036918], [-94254517949339161, 30875082916552795, -737993115889283, 2027864124215293, 155693872144255, 178916585271536, 51022745494970, 1767463350134, -209213462641850, 143206541235336, -69140166508863, 105461139708737, -47843863993221, 46587928060030], [-1931563100481045485, 36790337406669443, -198819100935439, -1287052373200978, 27486443341474, 399764911852038, 77493496773030, -139911652944152, 33004824376865, -8712295667436, -58502686772494, -208933468093086, 110572620962367, -15979200825352], [-3301584643843600604, -31727875183246012, 417479618602738, -989275691840750, -72701841698134, -150106095247970, -174208575097564, 36280173484260, 74731046583402, 431585945960882, 97729763747534, 163131320536770, 140560550645388, 56751992120044], [1568076924518611763, 1041715938886805, 2330341140148153, 1388798781739202, -65733287841995, -816329042209436, -205149281568804, -162479034899604, 28544685880518, 101608791840742, 40166279635667, -10181683320483, 123266232104789, 69689183040836], [1998705539633869860, -8804268711749740, -469407456165456, 10029832381546006, 47353329182592, -6429795126788, 119559920875704, -26864411531296, -19121918632412, 127720437228596, -49085758468320, 13741326164264, -47046296872012, 3143208823712], [-2680385544186026870, 1705282762497030, 749584005359218, -226709775915424, -243120478577802, -1056891795376904, -235262865670740, -216321504174338, -131315218930474, 126897104697590, 63499785352730, 49476226535976, -283874625828154, 20104627688666], [821020909439516574, 21912643135700566, -1095397197867744, 2869268854710819, -26799214979978, -90574786027480, -247714222617786, -53430632785697, -20476420377103, 55222120424195, 73472398690367, 70919723755471, -43856262725781, 42309866821155], [477549844172929022, 23491433969603640, -1187931260674200, -2564307701584640, -214814295818740, -411499972557764, -152274268530940, 23320633382436, -117462436536588, 164859258428232, -55773629564496, -45244522919176, 325684769487284, -41693665259444], [-3028971535500532926, -31301795024481826, 663679956020588, -5706438605300146, -249028030286926, 328050055741822, -21569556538504, -33263975106764, -77285282189356, -104397899335914, -29526350298846, -33287286656558, -230616584556342, -64254683345436], [-7131682768949113995, 91627267200802163, 1429685881731907, 9299993865015696, 137612049719319, -24593783846764, 271700356528872, 37949848362326, -13602483709196, -231523106977668, 40900968521359, 151925411291197, -181656146196503, -45050275778122], [-454835499165744227, -40319731191275977, -839524956165265, 12293100890101052, 89410123099705, 635264983256570, 234158675657678, 109206614377505, 9259332610819, -22314219190287, 60768608470134, 19624415187344, 144190426863882, 20488493865229], [5039647151100494359, -16988278544327178, -439993774592510, 2347666115823104, 82198005412271, 824001750955116, 95444440031148, 49287972141217, -33255695710798, -115001709342707, 99491127990601, -86510240699442, 21057264355352, 167270096881027], [-1526742239731310724, 19578383831533999, 1206128938686565, -10319122160951419, 145047713820428, -487473525805191, -116974152485830, 95188110953206, 240403370274608, 160377104822020, 23443568721388, -66953873072226, 332049979832684, -78531788034234], [1784984455597981823, -1715919607802087, -2926175121363415, -4878433746398283, 284757233259303, 447695485160022, -135872252777610, -61036400298416, 150235857089942, -22696632091788, -22674424990441, 6060744097355, -226338677091385, -50337502979960], [-792199572689166562, 53876432374625622, 1663369308018134, 5994323684144264, -190421733951550, -147628853812364, 320426051723392, 163463376014850, 330886310784318, 85778457749986, -5717352521866, -207035874561896, 235418025334578, 25948506734398], [1439920379164011327, 17339765557871523, -575258357052203, -8098735537384487, -110758659724777, 583342543845272, 22284567946958, 142898601383102, -331727140668938, -49682923916436, 162680745843637, 262666846691745, -182950696532133, -10359794038842], [-4535264631562891667, 41655417343296895, -1022502490381823, 8756041875728216, -196072803760273, -285404419550372, 207838952921794, 130444261768004, 126441376363588, 143610009573862, -50933708733025, -190577121973093, 493726600213313, 52160317533236]]
